.pf-v6-screen-reader {
  position: fixed;
  inset-block-start: 0;
  inset-inline-start: 0;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border: 0;
}

.pf-v6-screen-reader.pf-m-full-size {
  width: 100%;
  height: 100%;
}

.pf-v6-screen-reader.pf-m-absolute {
  position: absolute;
}

.pf-v6-m-tabular-nums {
  font-variant-numeric: tabular-nums;
}

.pf-v6-m-legacy-font {
  --pf-t--global--font--family--body: var(--pf-t--global--font--family--body--legacy);
  --pf-t--global--font--family--heading: var(--pf-t--global--font--family--heading--legacy);
  --pf-t--global--font--family--mono: var(--pf-t--global--font--family--mono--legacy);
  --pf-t--global--font--weight--body: var(--pf-t--global--font--weight--body--legacy);
  --pf-t--global--font--weight--body--bold: var(--pf-t--global--font--weight--body--bold--legacy);
  --pf-t--global--font--weight--heading: var(--pf-t--global--font--weight--heading--legacy);
  --pf-t--global--font--weight--heading--bold: var(--pf-t--global--font--weight--heading--bold--legacy);
}

.pf-v6-m-dir-rtl {
  --pf-v6-global--inverse--multiplier: -1;
  direction: rtl;
}

.pf-v6-m-dir-ltr {
  --pf-v6-global--inverse--multiplier: 1;
  direction: ltr;
}

:where(.pf-v6-m-dir-rtl, [dir=rtl]) .pf-v6-m-mirror-inline-rtl {
  scale: -1 1;
}

.pf-v6-m-no-motion {
  --pf-t--global--delay--400: 1ms !important;
  --pf-t--global--delay--300: 1ms !important;
  --pf-t--global--delay--200: 1ms !important;
  --pf-t--global--delay--100: 1ms !important;
  --pf-t--global--duration--600: 1ms !important;
  --pf-t--global--duration--500: 1ms !important;
  --pf-t--global--duration--400: 1ms !important;
  --pf-t--global--duration--300: 1ms !important;
  --pf-t--global--duration--200: 1ms !important;
  --pf-t--global--duration--100: 1ms !important;
  --pf-t--global--duration--50: 1ms !important;
}

:root {
  --pf-v6-global--danger-jiggle--AnimationDuration--Transform: var(--pf-t--global--motion--duration--fade--default);
  --pf-v6-global--danger-jiggle--AnimationTimingFunction--Transform: var(--pf-t--global--motion--timing-function--default);
}

@property --pf-v6-global--danger-jiggle--TranslateX {
  syntax: "<length>";
  inherits: false;
  initial-value: 0;
}

@keyframes pf-v6-global-danger-jiggle-motion {
  33% {
    --pf-v6-global--danger-jiggle--TranslateX: -2px;
  }

  66% {
    --pf-v6-global--danger-jiggle--TranslateX: 3px;
  }
}

@keyframes pf-v6-global-fade-in {
  from {
    opacity: 0;
  }

  to {
    opacity: 1;
  }
}

@keyframes pf-v6-global-fade-out {
  from {
    opacity: 1;
  }

  to {
    opacity: 0;
  }
}

@font-face {
  font-family: "Red Hat Text";
  font-style: normal;
  font-weight: 400 500;
  src: url("./assets/fonts/RedHatText/RedHatTextVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Text";
  font-style: italic;
  font-weight: 400 500;
  src: url("./assets/fonts/RedHatText/RedHatTextVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Display";
  font-style: normal;
  font-weight: 400 700;
  src: url("./assets/fonts/RedHatDisplay/RedHatDisplayVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Display";
  font-style: italic;
  font-weight: 400 700;
  src: url("./assets/fonts/RedHatDisplay/RedHatDisplayVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Mono";
  font-style: normal;
  font-weight: 400;
  src: url("./assets/fonts/RedHatMono/RedHatMonoVF.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "Red Hat Mono";
  font-style: italic;
  font-weight: 400;
  src: url("./assets/fonts/RedHatMono/RedHatMonoVF-Italic.woff2") format("woff2-variations");
  font-display: fallback;
}

@font-face {
  font-family: "pf-v6-pficon";
  src: url("./assets/pficon/pf-v6-pficon.woff2") format("woff2");
}

.pf-v6-pficon-zone:before,
.pf-v6-pficon-warning-triangle:before,
.pf-v6-pficon-volume:before,
.pf-v6-pficon-virtual-machine:before,
.pf-v6-pficon-users:before,
.pf-v6-pficon-user:before,
.pf-v6-pficon-unplugged:before,
.pf-v6-pficon-unlocked:before,
.pf-v6-pficon-unknown:before,
.pf-v6-pficon-trend-up:before,
.pf-v6-pficon-trend-down:before,
.pf-v6-pficon-treeview:before,
.pf-v6-pficon-topology:before,
.pf-v6-pficon-thumb-tack:before,
.pf-v6-pficon-tenant:before,
.pf-v6-pficon-task:before,
.pf-v6-pficon-storage-domain:before,
.pf-v6-pficon-spinner2:before,
.pf-v6-pficon-spinner:before,
.pf-v6-pficon-severity-undefined:before,
.pf-v6-pficon-severity-none:before,
.pf-v6-pficon-severity-moderate:before,
.pf-v6-pficon-severity-minor:before,
.pf-v6-pficon-severity-important:before,
.pf-v6-pficon-severity-critical:before,
.pf-v6-pficon-services:before,
.pf-v6-pficon-service:before,
.pf-v6-pficon-service-catalog:before,
.pf-v6-pficon-server:before,
.pf-v6-pficon-server-group:before,
.pf-v6-pficon-security:before,
.pf-v6-pficon-screen:before,
.pf-v6-pficon-save:before,
.pf-v6-pficon-running:before,
.pf-v6-pficon-resources-full:before,
.pf-v6-pficon-resources-empty:before,
.pf-v6-pficon-resources-almost-full:before,
.pf-v6-pficon-resources-almost-empty:before,
.pf-v6-pficon-resource-pool:before,
.pf-v6-pficon-repository:before,
.pf-v6-pficon-replicator:before,
.pf-v6-pficon-remove2:before,
.pf-v6-pficon-registry:before,
.pf-v6-pficon-regions:before,
.pf-v6-pficon-rebooting:before,
.pf-v6-pficon-rebalance:before,
.pf-v6-pficon-project:before,
.pf-v6-pficon-process-automation:before,
.pf-v6-pficon-private:before,
.pf-v6-pficon-print:before,
.pf-v6-pficon-port:before,
.pf-v6-pficon-plugged:before,
.pf-v6-pficon-pficon-vcenter:before,
.pf-v6-pficon-pficon-template:before,
.pf-v6-pficon-pficon-sort-common-desc:before,
.pf-v6-pficon-pficon-sort-common-asc:before,
.pf-v6-pficon-pficon-satellite:before,
.pf-v6-pficon-pficon-network-range:before,
.pf-v6-pficon-pficon-history:before,
.pf-v6-pficon-pficon-dragdrop:before,
.pf-v6-pficon-pending:before,
.pf-v6-pficon-paused:before,
.pf-v6-pficon-panel-open:before,
.pf-v6-pficon-panel-close:before,
.pf-v6-pficon-package:before,
.pf-v6-pficon-os-image:before,
.pf-v6-pficon-orders:before,
.pf-v6-pficon-optimize:before,
.pf-v6-pficon-openstack:before,
.pf-v6-pficon-openshift:before,
.pf-v6-pficon-open-drawer-right:before,
.pf-v6-pficon-on:before,
.pf-v6-pficon-on-running:before,
.pf-v6-pficon-ok:before,
.pf-v6-pficon-off:before,
.pf-v6-pficon-not-started:before,
.pf-v6-pficon-new-process:before,
.pf-v6-pficon-network:before,
.pf-v6-pficon-namespaces:before,
.pf-v6-pficon-multicluster:before,
.pf-v6-pficon-monitoring:before,
.pf-v6-pficon-module:before,
.pf-v6-pficon-migration:before,
.pf-v6-pficon-middleware:before,
.pf-v6-pficon-messages:before,
.pf-v6-pficon-memory:before,
.pf-v6-pficon-maintenance:before,
.pf-v6-pficon-locked:before,
.pf-v6-pficon-key:before,
.pf-v6-pficon-integration:before,
.pf-v6-pficon-infrastructure:before,
.pf-v6-pficon-info:before,
.pf-v6-pficon-in-progress:before,
.pf-v6-pficon-import:before,
.pf-v6-pficon-home:before,
.pf-v6-pficon-history:before,
.pf-v6-pficon-help:before,
.pf-v6-pficon-globe-route:before,
.pf-v6-pficon-folder-open:before,
.pf-v6-pficon-folder-close:before,
.pf-v6-pficon-flavor:before,
.pf-v6-pficon-filter:before,
.pf-v6-pficon-export:before,
.pf-v6-pficon-error-circle-o:before,
.pf-v6-pficon-equalizer:before,
.pf-v6-pficon-enterprise:before,
.pf-v6-pficon-enhancement:before,
.pf-v6-pficon-edit:before,
.pf-v6-pficon-domain:before,
.pf-v6-pficon-disconnected:before,
.pf-v6-pficon-degraded:before,
.pf-v6-pficon-data-source:before,
.pf-v6-pficon-data-sink:before,
.pf-v6-pficon-data-processor:before,
.pf-v6-pficon-critical-risk:before,
.pf-v6-pficon-cpu:before,
.pf-v6-pficon-container-node:before,
.pf-v6-pficon-connected:before,
.pf-v6-pficon-cluster:before,
.pf-v6-pficon-cloud-tenant:before,
.pf-v6-pficon-cloud-security:before,
.pf-v6-pficon-close:before,
.pf-v6-pficon-chat:before,
.pf-v6-pficon-catalog:before,
.pf-v6-pficon-bundle:before,
.pf-v6-pficon-builder-image:before,
.pf-v6-pficon-build:before,
.pf-v6-pficon-blueprint:before,
.pf-v6-pficon-bell:before,
.pf-v6-pficon-automation:before,
.pf-v6-pficon-attention-bell:before,
.pf-v6-pficon-asleep:before,
.pf-v6-pficon-arrow:before,
.pf-v6-pficon-applications:before,
.pf-v6-pficon-ansible-tower:before,
.pf-v6-pficon-add-circle-o:before {
  font-family: "pf-v6-pficon";
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-style: normal;
  font-variant: normal;
  font-weight: normal;
  text-decoration-line: none;
  text-transform: none;
}

.pf-v6-pficon-add-circle-o:before {
  content: "\e61b";
}

.pf-v6-pficon-ansible-tower:before {
  content: "\e950";
}

.pf-v6-pficon-applications:before {
  content: "\e936";
}

.pf-v6-pficon-arrow:before {
  content: "\e929";
}

.pf-v6-pficon-asleep:before {
  content: "\e92e";
}

.pf-v6-pficon-attention-bell:before {
  content: "\e951";
}

.pf-v6-pficon-automation:before {
  content: "\e937";
}

.pf-v6-pficon-bell:before {
  content: "\e952";
}

.pf-v6-pficon-blueprint:before {
  content: "\e915";
}

.pf-v6-pficon-build:before {
  content: "\e902";
}

.pf-v6-pficon-builder-image:before {
  content: "\e800";
}

.pf-v6-pficon-bundle:before {
  content: "\e918";
}

.pf-v6-pficon-catalog:before {
  content: "\e953";
}

.pf-v6-pficon-chat:before {
  content: "\e954";
}

.pf-v6-pficon-close:before {
  content: "\e60b";
}

.pf-v6-pficon-cloud-security:before {
  content: "\e903";
}

.pf-v6-pficon-cloud-tenant:before {
  content: "\e904";
}

.pf-v6-pficon-cluster:before {
  content: "\e620";
}

.pf-v6-pficon-connected:before {
  content: "\e938";
}

.pf-v6-pficon-container-node:before {
  content: "\e621";
}

.pf-v6-pficon-cpu:before {
  content: "\e927";
}

.pf-v6-pficon-critical-risk:before {
  content: "\e976";
}

.pf-v6-pficon-data-processor:before {
  content: "\e97b";
}

.pf-v6-pficon-data-sink:before {
  content: "\e978";
}

.pf-v6-pficon-data-source:before {
  content: "\e979";
}

.pf-v6-pficon-degraded:before {
  content: "\e91b";
}

.pf-v6-pficon-disconnected:before {
  content: "\e955";
}

.pf-v6-pficon-domain:before {
  content: "\e919";
}

.pf-v6-pficon-edit:before {
  content: "\e60a";
}

.pf-v6-pficon-enhancement:before {
  content: "\e93a";
}

.pf-v6-pficon-enterprise:before {
  content: "\e906";
}

.pf-v6-pficon-equalizer:before {
  content: "\e956";
}

.pf-v6-pficon-error-circle-o:before {
  content: "\e926";
}

.pf-v6-pficon-export:before {
  content: "\e616";
}

.pf-v6-pficon-filter:before {
  content: "\e943";
}

.pf-v6-pficon-flavor:before {
  content: "\e957";
}

.pf-v6-pficon-folder-close:before {
  content: "\e607";
}

.pf-v6-pficon-folder-open:before {
  content: "\e606";
}

.pf-v6-pficon-globe-route:before {
  content: "\e958";
}

.pf-v6-pficon-help:before {
  content: "\e605";
}

.pf-v6-pficon-history:before {
  content: "\e617";
}

.pf-v6-pficon-home:before {
  content: "\e618";
}

.pf-v6-pficon-import:before {
  content: "\e615";
}

.pf-v6-pficon-in-progress:before {
  content: "\e933";
}

.pf-v6-pficon-info:before {
  content: "\e92b";
}

.pf-v6-pficon-infrastructure:before {
  content: "\e93d";
}

.pf-v6-pficon-integration:before {
  content: "\e948";
}

.pf-v6-pficon-key:before {
  content: "\e924";
}

.pf-v6-pficon-locked:before {
  content: "\e923";
}

.pf-v6-pficon-maintenance:before {
  content: "\e932";
}

.pf-v6-pficon-memory:before {
  content: "\e908";
}

.pf-v6-pficon-messages:before {
  content: "\e603";
}

.pf-v6-pficon-middleware:before {
  content: "\e917";
}

.pf-v6-pficon-migration:before {
  content: "\e931";
}

.pf-v6-pficon-module:before {
  content: "\e959";
}

.pf-v6-pficon-monitoring:before {
  content: "\e95a";
}

.pf-v6-pficon-multicluster:before {
  content: "\e97c";
}

.pf-v6-pficon-namespaces:before {
  content: "\e95b";
}

.pf-v6-pficon-network:before {
  content: "\e909";
}

.pf-v6-pficon-new-process:before {
  content: "\e95c";
}

.pf-v6-pficon-not-started:before {
  content: "\e95d";
}

.pf-v6-pficon-off:before {
  content: "\e92d";
}

.pf-v6-pficon-ok:before {
  content: "\e602";
}

.pf-v6-pficon-on-running:before {
  content: "\e925";
}

.pf-v6-pficon-on:before {
  content: "\e92c";
}

.pf-v6-pficon-open-drawer-right:before {
  content: "\e977";
}

.pf-v6-pficon-openshift:before {
  content: "\e95e";
}

.pf-v6-pficon-openstack:before {
  content: "\e95f";
}

.pf-v6-pficon-optimize:before {
  content: "\e93e";
}

.pf-v6-pficon-orders:before {
  content: "\e93f";
}

.pf-v6-pficon-os-image:before {
  content: "\e960";
}

.pf-v6-pficon-package:before {
  content: "\e961";
}

.pf-v6-pficon-panel-close:before {
  content: "\e962";
}

.pf-v6-pficon-panel-open:before {
  content: "\e963";
}

.pf-v6-pficon-paused:before {
  content: "\e92f";
}

.pf-v6-pficon-pending:before {
  content: "\e964";
}

.pf-v6-pficon-pficon-dragdrop:before {
  content: "\e965";
}

.pf-v6-pficon-pficon-history:before {
  content: "\e966";
}

.pf-v6-pficon-pficon-network-range:before {
  content: "\e967";
}

.pf-v6-pficon-pficon-satellite:before {
  content: "\e968";
}

.pf-v6-pficon-pficon-sort-common-asc:before {
  content: "\e94e";
}

.pf-v6-pficon-pficon-sort-common-desc:before {
  content: "\e94f";
}

.pf-v6-pficon-pficon-template:before {
  content: "\e94c";
}

.pf-v6-pficon-pficon-vcenter:before {
  content: "\e969";
}

.pf-v6-pficon-plugged:before {
  content: "\e96a";
}

.pf-v6-pficon-port:before {
  content: "\e96b";
}

.pf-v6-pficon-print:before {
  content: "\e612";
}

.pf-v6-pficon-private:before {
  content: "\e914";
}

.pf-v6-pficon-process-automation:before {
  content: "\e949";
}

.pf-v6-pficon-project:before {
  content: "\e96c";
}

.pf-v6-pficon-rebalance:before {
  content: "\e91c";
}

.pf-v6-pficon-rebooting:before {
  content: "\e96d";
}

.pf-v6-pficon-regions:before {
  content: "\e90a";
}

.pf-v6-pficon-registry:before {
  content: "\e623";
}

.pf-v6-pficon-remove2:before {
  content: "\e96e";
}

.pf-v6-pficon-replicator:before {
  content: "\e624";
}

.pf-v6-pficon-repository:before {
  content: "\e90b";
}

.pf-v6-pficon-resource-pool:before {
  content: "\e90c";
}

.pf-v6-pficon-resources-almost-empty:before {
  content: "\e91d";
}

.pf-v6-pficon-resources-almost-full:before {
  content: "\e912";
}

.pf-v6-pficon-resources-empty:before {
  content: "\e96f";
}

.pf-v6-pficon-resources-full:before {
  content: "\e913";
}

.pf-v6-pficon-running:before {
  content: "\e970";
}

.pf-v6-pficon-save:before {
  content: "\e601";
}

.pf-v6-pficon-screen:before {
  content: "\e971";
}

.pf-v6-pficon-security:before {
  content: "\e946";
}

.pf-v6-pficon-server-group:before {
  content: "\e91a";
}

.pf-v6-pficon-server:before {
  content: "\e90d";
}

.pf-v6-pficon-service-catalog:before {
  content: "\e972";
}

.pf-v6-pficon-service:before {
  content: "\e61e";
}

.pf-v6-pficon-services:before {
  content: "\e947";
}

.pf-v6-pficon-severity-critical:before {
  content: "\e97e";
}

.pf-v6-pficon-severity-important:before {
  content: "\e97f";
}

.pf-v6-pficon-severity-minor:before {
  content: "\e980";
}

.pf-v6-pficon-severity-moderate:before {
  content: "\e981";
}

.pf-v6-pficon-severity-none:before {
  content: "\e982";
}

.pf-v6-pficon-severity-undefined:before {
  content: "\e983";
}

.pf-v6-pficon-spinner:before {
  content: "\e973";
}

.pf-v6-pficon-spinner2:before {
  content: "\e613";
}

.pf-v6-pficon-storage-domain:before {
  content: "\e90e";
}

.pf-v6-pficon-task:before {
  content: "\e974";
}

.pf-v6-pficon-tenant:before {
  content: "\e916";
}

.pf-v6-pficon-thumb-tack:before {
  content: "\e920";
}

.pf-v6-pficon-topology:before {
  content: "\e608";
}

.pf-v6-pficon-treeview:before {
  content: "\e97d";
}

.pf-v6-pficon-trend-down:before {
  content: "\e900";
}

.pf-v6-pficon-trend-up:before {
  content: "\e901";
}

.pf-v6-pficon-unknown:before {
  content: "\e935";
}

.pf-v6-pficon-unlocked:before {
  content: "\e922";
}

.pf-v6-pficon-unplugged:before {
  content: "\e942";
}

.pf-v6-pficon-user:before {
  content: "\e91e";
}

.pf-v6-pficon-users:before {
  content: "\e91f";
}

.pf-v6-pficon-virtual-machine:before {
  content: "\e90f";
}

.pf-v6-pficon-volume:before {
  content: "\e910";
}

.pf-v6-pficon-warning-triangle:before {
  content: "\e975";
}

.pf-v6-pficon-zone:before {
  content: "\e911";
}

.pf-v6-svg {
  width: 1em;
  height: 1em;
  vertical-align: -0.125em;
}

:root {
  --pf-v6-global--inverse--multiplier: 1;
  --pf-t--color--black: #000000;
  --pf-t--color--blue--10: #e0f0ff;
  --pf-t--color--blue--20: #b9dafc;
  --pf-t--color--blue--30: #92c5f9;
  --pf-t--color--blue--40: #4394e5;
  --pf-t--color--blue--50: #0066cc;
  --pf-t--color--blue--60: #004d99;
  --pf-t--color--blue--70: #003366;
  --pf-t--color--blue--80: #032142;
  --pf-t--color--gray--10: #f2f2f2;
  --pf-t--color--gray--20: #e0e0e0;
  --pf-t--color--gray--30: #c7c7c7;
  --pf-t--color--gray--40: #a3a3a3;
  --pf-t--color--gray--50: #707070;
  --pf-t--color--gray--60: #4d4d4d;
  --pf-t--color--gray--70: #383838;
  --pf-t--color--gray--80: #292929;
  --pf-t--color--gray--90: #1f1f1f;
  --pf-t--color--gray--95: #151515;
  --pf-t--color--green--10: #e9f7df;
  --pf-t--color--green--20: #d1f1bb;
  --pf-t--color--green--30: #afdc8f;
  --pf-t--color--green--40: #87bb62;
  --pf-t--color--green--50: #63993d;
  --pf-t--color--green--60: #3d7317;
  --pf-t--color--green--70: #204d00;
  --pf-t--color--green--80: #183301;
  --pf-t--color--orange--10: #ffe8cc;
  --pf-t--color--orange--20: #fccb8f;
  --pf-t--color--orange--30: #f8ae54;
  --pf-t--color--orange--40: #f5921b;
  --pf-t--color--orange--50: #ca6c0f;
  --pf-t--color--orange--60: #9e4a06;
  --pf-t--color--orange--70: #732e00;
  --pf-t--color--orange--80: #4d1f00;
  --pf-t--color--purple--10: #ece6ff;
  --pf-t--color--purple--20: #d0c5f4;
  --pf-t--color--purple--30: #b6a6e9;
  --pf-t--color--purple--40: #876fd4;
  --pf-t--color--purple--50: #5e40be;
  --pf-t--color--purple--60: #3d2785;
  --pf-t--color--purple--70: #21134d;
  --pf-t--color--purple--80: #1b0d33;
  --pf-t--color--red--10: #fce3e3;
  --pf-t--color--red--20: #fbc5c5;
  --pf-t--color--red--30: #f9a8a8;
  --pf-t--color--red--40: #f56e6e;
  --pf-t--color--red--50: #ee0000;
  --pf-t--color--red--60: #a60000;
  --pf-t--color--red--70: #5f0000;
  --pf-t--color--red--80: #3f0000;
  --pf-t--color--red-orange--10: #ffe3d9;
  --pf-t--color--red-orange--20: #fbbea8;
  --pf-t--color--red-orange--30: #f89b78;
  --pf-t--color--red-orange--40: #f4784a;
  --pf-t--color--red-orange--50: #f0561d;
  --pf-t--color--red-orange--60: #b1380b;
  --pf-t--color--red-orange--70: #731f00;
  --pf-t--color--red-orange--80: #4c1405;
  --pf-t--color--teal--10: #daf2f2;
  --pf-t--color--teal--20: #b9e5e5;
  --pf-t--color--teal--30: #9ad8d8;
  --pf-t--color--teal--40: #63bdbd;
  --pf-t--color--teal--50: #37a3a3;
  --pf-t--color--teal--60: #147878;
  --pf-t--color--teal--70: #004d4d;
  --pf-t--color--teal--80: #003333;
  --pf-t--color--white: #ffffff;
  --pf-t--color--yellow--10: #fff4cc;
  --pf-t--color--yellow--20: #ffe072;
  --pf-t--color--yellow--30: #ffcc17;
  --pf-t--color--yellow--40: #dca614;
  --pf-t--color--yellow--50: #b98412;
  --pf-t--color--yellow--60: #96640f;
  --pf-t--color--yellow--70: #73480b;
  --pf-t--color--yellow--80: #54330b;
  --pf-t--global--background--color--500: rgba(21, 21, 21, 0.2000);
  --pf-t--global--background--color--600: rgba(199, 199, 199, 0.2500);
  --pf-t--global--background--color--action--plain--default: rgba(255, 255, 255, 0.0000);
  --pf-t--global--border--color--high-contrast: rgba(255, 255, 255, 0.0000);
  --pf-t--global--border--radius--0: 0px;
  --pf-t--global--border--radius--100: 4px;
  --pf-t--global--border--radius--200: 6px;
  --pf-t--global--border--radius--300: 16px;
  --pf-t--global--border--radius--400: 24px;
  --pf-t--global--border--radius--500: 999px;
  --pf-t--global--border--width--100: 1px;
  --pf-t--global--border--width--200: 2px;
  --pf-t--global--border--width--300: 3px;
  --pf-t--global--border--width--400: 4px;
  --pf-t--global--border--width--action--plain--clicked: 0px;
  --pf-t--global--border--width--action--plain--default: 0px;
  --pf-t--global--border--width--action--plain--hover: 0px;
  --pf-t--global--border--width--high-contrast--extra-strong: 0px;
  --pf-t--global--border--width--high-contrast--regular: 0px;
  --pf-t--global--border--width--high-contrast--strong: 0px;
  --pf-t--global--box-shadow--X--100: -10px;
  --pf-t--global--box-shadow--X--200: -4px;
  --pf-t--global--box-shadow--X--300: -1px;
  --pf-t--global--box-shadow--X--400: 0px;
  --pf-t--global--box-shadow--X--50: -20px;
  --pf-t--global--box-shadow--X--500: 1px;
  --pf-t--global--box-shadow--X--600: 4px;
  --pf-t--global--box-shadow--X--700: 10px;
  --pf-t--global--box-shadow--X--800: 20px;
  --pf-t--global--box-shadow--Y--100: -10px;
  --pf-t--global--box-shadow--Y--200: -4px;
  --pf-t--global--box-shadow--Y--300: -1px;
  --pf-t--global--box-shadow--Y--400: 0px;
  --pf-t--global--box-shadow--Y--50: -20px;
  --pf-t--global--box-shadow--Y--500: 1px;
  --pf-t--global--box-shadow--Y--600: 4px;
  --pf-t--global--box-shadow--Y--700: 10px;
  --pf-t--global--box-shadow--Y--800: 20px;
  --pf-t--global--box-shadow--blur--100: 4px;
  --pf-t--global--box-shadow--blur--200: 9px;
  --pf-t--global--box-shadow--blur--300: 20px;
  --pf-t--global--box-shadow--color--100: rgba(41, 41, 41, 0.1500);
  --pf-t--global--box-shadow--color--200: rgba(41, 41, 41, 0.2000);
  --pf-t--global--box-shadow--spread--100: 0px;
  --pf-t--global--box-shadow--spread--200: -4px;
  --pf-t--global--box-shadow--spread--300: -8px;
  --pf-t--global--box-shadow--spread--400: -20px;
  --pf-t--global--breakpoint--100: 0rem;
  --pf-t--global--breakpoint--200: 36rem;
  --pf-t--global--breakpoint--250: 40rem;
  --pf-t--global--breakpoint--300: 48rem;
  --pf-t--global--breakpoint--350: 60rem;
  --pf-t--global--breakpoint--400: 62rem;
  --pf-t--global--breakpoint--500: 75rem;
  --pf-t--global--breakpoint--550: 80rem;
  --pf-t--global--breakpoint--600: 90.625rem;
  --pf-t--global--color--nonstatus--green--400: #3d7019;
  --pf-t--global--color--status--success--150: #3d7019;
  --pf-t--global--delay--100: 0ms;
  --pf-t--global--delay--200: 50ms;
  --pf-t--global--delay--300: 100ms;
  --pf-t--global--delay--400: 7000ms;
  --pf-t--global--duration--100: 100ms;
  --pf-t--global--duration--200: 200ms;
  --pf-t--global--duration--300: 300ms;
  --pf-t--global--duration--400: 400ms;
  --pf-t--global--duration--50: 50ms;
  --pf-t--global--duration--500: 500ms;
  --pf-t--global--duration--600: 600ms;
  --pf-t--global--focus-ring--position--inset: -4px;
  --pf-t--global--focus-ring--position--offset: 2px;
  --pf-t--global--focus-ring--width--inset: 3px;
  --pf-t--global--focus-ring--width--offset: 2px;
  --pf-t--global--font--family--100: "Red Hat Text", "RedHatText", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--200: "Red Hat Display", "RedHatDisplay", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--300: "Red Hat Mono", "RedHatMono", "Courier New", Courier, monospace;
  --pf-t--global--font--line-height--100: 1.3;
  --pf-t--global--font--line-height--200: 1.5;
  --pf-t--global--font--size--100: 0.75rem;
  --pf-t--global--font--size--200: 0.875rem;
  --pf-t--global--font--size--300: 1rem;
  --pf-t--global--font--size--400: 1.125rem;
  --pf-t--global--font--size--500: 1.25rem;
  --pf-t--global--font--size--600: 1.5rem;
  --pf-t--global--font--size--700: 1.75rem;
  --pf-t--global--font--size--800: 2.25rem;
  --pf-t--global--font--weight--100: 400;
  --pf-t--global--font--weight--200: 500;
  --pf-t--global--font--weight--300: 500;
  --pf-t--global--font--weight--400: 700;
  --pf-t--global--icon--size--100: 0.75rem;
  --pf-t--global--icon--size--200: 0.875rem;
  --pf-t--global--icon--size--250: 1rem;
  --pf-t--global--icon--size--300: 1.5rem;
  --pf-t--global--icon--size--400: 3.5rem;
  --pf-t--global--icon--size--500: 6rem;
  --pf-t--global--spacer--100: 0.25rem;
  --pf-t--global--spacer--200: 0.5rem;
  --pf-t--global--spacer--300: 1rem;
  --pf-t--global--spacer--400: 1.5rem;
  --pf-t--global--spacer--500: 2rem;
  --pf-t--global--spacer--600: 3rem;
  --pf-t--global--spacer--700: 4rem;
  --pf-t--global--spacer--800: 5rem;
  --pf-t--global--text-decoration--line--100: none;
  --pf-t--global--text-decoration--line--200: underline;
  --pf-t--global--text-decoration--style--100: solid;
  --pf-t--global--text-decoration--style--200: dashed;
  --pf-t--global--timing-function--100: cubic-bezier(.4, 0, .7, .2);
  --pf-t--global--timing-function--200: cubic-bezier(.4, 0, .2, 1);
  --pf-t--global--timing-function--300: cubic-bezier(0, 0, .2, 1);
  --pf-t--global--z-index--100: 100;
  --pf-t--global--z-index--200: 200;
  --pf-t--global--z-index--300: 300;
  --pf-t--global--z-index--400: 400;
  --pf-t--global--z-index--500: 500;
  --pf-t--global--z-index--600: 600;
  --pf-t--global--background--color--100: var(--pf-t--color--white);
  --pf-t--global--background--color--200: var(--pf-t--color--gray--10);
  --pf-t--global--background--color--300: var(--pf-t--color--gray--20);
  --pf-t--global--background--color--400: var(--pf-t--color--gray--80);
  --pf-t--global--background--color--450: var(--pf-t--color--gray--70);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--background--color--500);
  --pf-t--global--background--color--highlight--100: var(--pf-t--color--yellow--30);
  --pf-t--global--background--color--highlight--200: var(--pf-t--color--yellow--40);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--background--color--600);
  --pf-t--global--border--color--100: var(--pf-t--color--gray--30);
  --pf-t--global--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--border--color--300: var(--pf-t--color--gray--50);
  --pf-t--global--border--color--400: var(--pf-t--color--gray--60);
  --pf-t--global--border--color--50: var(--pf-t--color--gray--20);
  --pf-t--global--border--radius--large: var(--pf-t--global--border--radius--400);
  --pf-t--global--border--radius--medium: var(--pf-t--global--border--radius--300);
  --pf-t--global--border--radius--pill: var(--pf-t--global--border--radius--500);
  --pf-t--global--border--radius--sharp: var(--pf-t--global--border--radius--0);
  --pf-t--global--border--radius--small: var(--pf-t--global--border--radius--200);
  --pf-t--global--border--radius--tiny: var(--pf-t--global--border--radius--100);
  --pf-t--global--border--width--action--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--action--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--status--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--status--read: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--control--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--clicked: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--extra-strong: var(--pf-t--global--border--width--300);
  --pf-t--global--border--width--main--default: var(--pf-t--global--border--width--400);
  --pf-t--global--border--width--regular: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--strong: var(--pf-t--global--border--width--200);
  --pf-t--global--box-shadow--X--lg--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--left: var(--pf-t--global--box-shadow--X--50);
  --pf-t--global--box-shadow--X--lg--right: var(--pf-t--global--box-shadow--X--800);
  --pf-t--global--box-shadow--X--lg--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--left: var(--pf-t--global--box-shadow--X--100);
  --pf-t--global--box-shadow--X--md--right: var(--pf-t--global--box-shadow--X--700);
  --pf-t--global--box-shadow--X--md--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--left: var(--pf-t--global--box-shadow--X--200);
  --pf-t--global--box-shadow--X--sm--right: var(--pf-t--global--box-shadow--X--600);
  --pf-t--global--box-shadow--X--sm--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--Y--lg--bottom: var(--pf-t--global--box-shadow--Y--800);
  --pf-t--global--box-shadow--Y--lg--default: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--lg--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--top: var(--pf-t--global--box-shadow--Y--50);
  --pf-t--global--box-shadow--Y--md--bottom: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--md--default: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--md--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--top: var(--pf-t--global--box-shadow--Y--100);
  --pf-t--global--box-shadow--Y--sm--bottom: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--sm--default: var(--pf-t--global--box-shadow--Y--500);
  --pf-t--global--box-shadow--Y--sm--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--top: var(--pf-t--global--box-shadow--Y--200);
  --pf-t--global--box-shadow--blur--lg: var(--pf-t--global--box-shadow--blur--300);
  --pf-t--global--box-shadow--blur--md: var(--pf-t--global--box-shadow--blur--200);
  --pf-t--global--box-shadow--blur--sm: var(--pf-t--global--box-shadow--blur--100);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--spread--lg--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--lg--directional: var(--pf-t--global--box-shadow--spread--400);
  --pf-t--global--box-shadow--spread--md--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--md--directional: var(--pf-t--global--box-shadow--spread--300);
  --pf-t--global--box-shadow--spread--sm--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--sm--directional: var(--pf-t--global--box-shadow--spread--200);
  --pf-t--global--breakpoint--2xl: var(--pf-t--global--breakpoint--600);
  --pf-t--global--breakpoint--height--2xl: var(--pf-t--global--breakpoint--550);
  --pf-t--global--breakpoint--height--lg: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--height--md: var(--pf-t--global--breakpoint--250);
  --pf-t--global--breakpoint--height--sm: var(--pf-t--global--breakpoint--100);
  --pf-t--global--breakpoint--height--xl: var(--pf-t--global--breakpoint--350);
  --pf-t--global--breakpoint--lg: var(--pf-t--global--breakpoint--400);
  --pf-t--global--breakpoint--md: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--sm: var(--pf-t--global--breakpoint--200);
  --pf-t--global--breakpoint--xl: var(--pf-t--global--breakpoint--500);
  --pf-t--global--breakpoint--xs: var(--pf-t--global--breakpoint--100);
  --pf-t--global--color--brand--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--brand--200: var(--pf-t--color--blue--50);
  --pf-t--global--color--brand--300: var(--pf-t--color--blue--60);
  --pf-t--global--color--brand--400: var(--pf-t--color--blue--70);
  --pf-t--global--color--brand--500: var(--pf-t--color--blue--80);
  --pf-t--global--color--disabled--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--disabled--200: var(--pf-t--color--gray--40);
  --pf-t--global--color--disabled--300: var(--pf-t--color--gray--60);
  --pf-t--global--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--favorite--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--favorite--300: var(--pf-t--color--yellow--70);
  --pf-t--global--color--favorite--400: var(--pf-t--color--yellow--80);
  --pf-t--global--color--nonstatus--blue--100: var(--pf-t--color--blue--20);
  --pf-t--global--color--nonstatus--blue--200: var(--pf-t--color--blue--30);
  --pf-t--global--color--nonstatus--blue--300: var(--pf-t--color--blue--40);
  --pf-t--global--color--nonstatus--blue--400: var(--pf-t--color--blue--60);
  --pf-t--global--color--nonstatus--blue--500: var(--pf-t--color--blue--70);
  --pf-t--global--color--nonstatus--gray--100: var(--pf-t--color--gray--20);
  --pf-t--global--color--nonstatus--gray--200: var(--pf-t--color--gray--30);
  --pf-t--global--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--color--nonstatus--gray--400: var(--pf-t--color--gray--60);
  --pf-t--global--color--nonstatus--gray--50: var(--pf-t--color--gray--10);
  --pf-t--global--color--nonstatus--gray--500: var(--pf-t--color--gray--70);
  --pf-t--global--color--nonstatus--green--100: var(--pf-t--color--green--20);
  --pf-t--global--color--nonstatus--green--200: var(--pf-t--color--green--30);
  --pf-t--global--color--nonstatus--green--300: var(--pf-t--color--green--40);
  --pf-t--global--color--nonstatus--green--500: var(--pf-t--color--green--70);
  --pf-t--global--color--nonstatus--orange--100: var(--pf-t--color--orange--20);
  --pf-t--global--color--nonstatus--orange--200: var(--pf-t--color--orange--30);
  --pf-t--global--color--nonstatus--orange--300: var(--pf-t--color--orange--40);
  --pf-t--global--color--nonstatus--orange--400: var(--pf-t--color--orange--60);
  --pf-t--global--color--nonstatus--orange--500: var(--pf-t--color--orange--70);
  --pf-t--global--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--20);
  --pf-t--global--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--30);
  --pf-t--global--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--40);
  --pf-t--global--color--nonstatus--orangered--400: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--nonstatus--orangered--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--nonstatus--purple--100: var(--pf-t--color--purple--20);
  --pf-t--global--color--nonstatus--purple--200: var(--pf-t--color--purple--30);
  --pf-t--global--color--nonstatus--purple--300: var(--pf-t--color--purple--40);
  --pf-t--global--color--nonstatus--purple--400: var(--pf-t--color--purple--50);
  --pf-t--global--color--nonstatus--purple--500: var(--pf-t--color--purple--60);
  --pf-t--global--color--nonstatus--red--100: var(--pf-t--color--red--20);
  --pf-t--global--color--nonstatus--red--200: var(--pf-t--color--red--30);
  --pf-t--global--color--nonstatus--red--300: var(--pf-t--color--red--40);
  --pf-t--global--color--nonstatus--red--400: var(--pf-t--color--red--60);
  --pf-t--global--color--nonstatus--red--500: var(--pf-t--color--red--70);
  --pf-t--global--color--nonstatus--teal--100: var(--pf-t--color--teal--20);
  --pf-t--global--color--nonstatus--teal--200: var(--pf-t--color--teal--30);
  --pf-t--global--color--nonstatus--teal--300: var(--pf-t--color--teal--40);
  --pf-t--global--color--nonstatus--teal--400: var(--pf-t--color--teal--70);
  --pf-t--global--color--nonstatus--teal--500: var(--pf-t--color--teal--80);
  --pf-t--global--color--nonstatus--yellow--100: var(--pf-t--color--yellow--20);
  --pf-t--global--color--nonstatus--yellow--200: var(--pf-t--color--yellow--30);
  --pf-t--global--color--nonstatus--yellow--300: var(--pf-t--color--yellow--40);
  --pf-t--global--color--nonstatus--yellow--400: var(--pf-t--color--yellow--70);
  --pf-t--global--color--nonstatus--yellow--500: var(--pf-t--color--yellow--80);
  --pf-t--global--color--severity--critical--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--severity--important--100: var(--pf-t--color--orange--50);
  --pf-t--global--color--severity--important--200: var(--pf-t--color--orange--60);
  --pf-t--global--color--severity--minor--100: var(--pf-t--color--gray--50);
  --pf-t--global--color--severity--minor--200: var(--pf-t--color--gray--80);
  --pf-t--global--color--severity--moderate--100: var(--pf-t--color--yellow--40);
  --pf-t--global--color--severity--moderate--200: var(--pf-t--color--yellow--70);
  --pf-t--global--color--severity--none--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--severity--none--200: var(--pf-t--color--blue--60);
  --pf-t--global--color--severity--undefined--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--severity--undefined--200: var(--pf-t--color--gray--60);
  --pf-t--global--color--status--custom--100: var(--pf-t--color--teal--60);
  --pf-t--global--color--status--custom--200: var(--pf-t--color--teal--70);
  --pf-t--global--color--status--custom--300: var(--pf-t--color--teal--80);
  --pf-t--global--color--status--danger--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--status--danger--200: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--status--danger--300: var(--pf-t--color--red-orange--80);
  --pf-t--global--color--status--info--100: var(--pf-t--color--purple--50);
  --pf-t--global--color--status--info--200: var(--pf-t--color--purple--60);
  --pf-t--global--color--status--info--300: var(--pf-t--color--purple--70);
  --pf-t--global--color--status--success--100: var(--pf-t--color--green--60);
  --pf-t--global--color--status--success--200: var(--pf-t--color--green--70);
  --pf-t--global--color--status--success--300: var(--pf-t--color--green--80);
  --pf-t--global--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--status--warning--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--status--warning--300: var(--pf-t--color--yellow--50);
  --pf-t--global--color--status--warning--400: var(--pf-t--color--yellow--60);
  --pf-t--global--color--status--warning--500: var(--pf-t--color--yellow--70);
  --pf-t--global--color--status--warning--600: var(--pf-t--color--yellow--80);
  --pf-t--global--focus-ring--color--100: var(--pf-t--color--blue--50);
  --pf-t--global--focus-ring--color--200: var(--pf-t--color--blue--60);
  --pf-t--global--font--family--body: var(--pf-t--global--font--family--100);
  --pf-t--global--font--family--heading: var(--pf-t--global--font--family--200);
  --pf-t--global--font--family--mono: var(--pf-t--global--font--family--300);
  --pf-t--global--font--line-height--body: var(--pf-t--global--font--line-height--200);
  --pf-t--global--font--line-height--heading: var(--pf-t--global--font--line-height--100);
  --pf-t--global--font--size--2xl: var(--pf-t--global--font--size--600);
  --pf-t--global--font--size--3xl: var(--pf-t--global--font--size--700);
  --pf-t--global--font--size--4xl: var(--pf-t--global--font--size--800);
  --pf-t--global--font--size--lg: var(--pf-t--global--font--size--400);
  --pf-t--global--font--size--md: var(--pf-t--global--font--size--300);
  --pf-t--global--font--size--sm: var(--pf-t--global--font--size--200);
  --pf-t--global--font--size--xl: var(--pf-t--global--font--size--500);
  --pf-t--global--font--size--xs: var(--pf-t--global--font--size--100);
  --pf-t--global--font--weight--body--bold: var(--pf-t--global--font--weight--200);
  --pf-t--global--font--weight--body--default: var(--pf-t--global--font--weight--100);
  --pf-t--global--font--weight--heading--bold: var(--pf-t--global--font--weight--400);
  --pf-t--global--font--weight--heading--default: var(--pf-t--global--font--weight--300);
  --pf-t--global--icon--color--100: var(--pf-t--color--gray--90);
  --pf-t--global--icon--color--150: var(--pf-t--color--gray--60);
  --pf-t--global--icon--color--200: var(--pf-t--color--gray--50);
  --pf-t--global--icon--color--300: var(--pf-t--color--white);
  --pf-t--global--icon--size--2xl: var(--pf-t--global--icon--size--400);
  --pf-t--global--icon--size--3xl: var(--pf-t--global--icon--size--500);
  --pf-t--global--icon--size--lg: var(--pf-t--global--icon--size--250);
  --pf-t--global--icon--size--md: var(--pf-t--global--icon--size--200);
  --pf-t--global--icon--size--sm: var(--pf-t--global--icon--size--100);
  --pf-t--global--icon--size--xl: var(--pf-t--global--icon--size--300);
  --pf-t--global--motion--delay--default: var(--pf-t--global--delay--300);
  --pf-t--global--motion--delay--long: var(--pf-t--global--delay--400);
  --pf-t--global--motion--delay--none: var(--pf-t--global--delay--100);
  --pf-t--global--motion--delay--short: var(--pf-t--global--delay--200);
  --pf-t--global--motion--duration--2xl: var(--pf-t--global--duration--500);
  --pf-t--global--motion--duration--3xl: var(--pf-t--global--duration--600);
  --pf-t--global--motion--duration--lg: var(--pf-t--global--duration--300);
  --pf-t--global--motion--duration--md: var(--pf-t--global--duration--200);
  --pf-t--global--motion--duration--sm: var(--pf-t--global--duration--100);
  --pf-t--global--motion--duration--xl: var(--pf-t--global--duration--400);
  --pf-t--global--motion--duration--xs: var(--pf-t--global--duration--50);
  --pf-t--global--motion--timing-function--accelerate: var(--pf-t--global--timing-function--100);
  --pf-t--global--motion--timing-function--decelerate: var(--pf-t--global--timing-function--300);
  --pf-t--global--motion--timing-function--default: var(--pf-t--global--timing-function--200);
  --pf-t--global--spacer--2xl: var(--pf-t--global--spacer--600);
  --pf-t--global--spacer--3xl: var(--pf-t--global--spacer--700);
  --pf-t--global--spacer--4xl: var(--pf-t--global--spacer--800);
  --pf-t--global--spacer--lg: var(--pf-t--global--spacer--400);
  --pf-t--global--spacer--md: var(--pf-t--global--spacer--300);
  --pf-t--global--spacer--sm: var(--pf-t--global--spacer--200);
  --pf-t--global--spacer--xl: var(--pf-t--global--spacer--500);
  --pf-t--global--spacer--xs: var(--pf-t--global--spacer--100);
  --pf-t--global--text--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--text--color--200: var(--pf-t--color--gray--60);
  --pf-t--global--text--color--250: var(--pf-t--color--gray--70);
  --pf-t--global--text--color--300: var(--pf-t--color--white);
  --pf-t--global--text--color--400: var(--pf-t--color--red-orange--40);
  --pf-t--global--text--color--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--text--color--link--100: var(--pf-t--color--blue--50);
  --pf-t--global--text--color--link--200: var(--pf-t--color--blue--60);
  --pf-t--global--text--color--link--250: var(--pf-t--color--blue--70);
  --pf-t--global--text--color--link--300: var(--pf-t--color--purple--50);
  --pf-t--global--text--color--link--350: var(--pf-t--color--purple--60);
  --pf-t--global--text-decoration--editable-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--editable-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--link--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--style--default: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--text-decoration--link--style--hover: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--z-index--2xl: var(--pf-t--global--z-index--600);
  --pf-t--global--z-index--lg: var(--pf-t--global--z-index--400);
  --pf-t--global--z-index--md: var(--pf-t--global--z-index--300);
  --pf-t--global--z-index--sm: var(--pf-t--global--z-index--200);
  --pf-t--global--z-index--xl: var(--pf-t--global--z-index--500);
  --pf-t--global--z-index--xs: var(--pf-t--global--z-index--100);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--color--disabled--100);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--primary--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--background--color--300);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--background--color--300);
  --pf-t--global--border--color--clicked: var(--pf-t--global--color--brand--200);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--border--color--100);
  --pf-t--global--border--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--border--color--hover: var(--pf-t--global--color--brand--100);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--300);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--300);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--200);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--300);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--300);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--300);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--300);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--300);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--300);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--300);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--300);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--300);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--300);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--300);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--300);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--300);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--300);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--border--color--300);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--200);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--color--brand--300);
  --pf-t--global--color--brand--default: var(--pf-t--global--color--brand--200);
  --pf-t--global--color--brand--hover: var(--pf-t--global--color--brand--300);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--color--favorite--200);
  --pf-t--global--color--favorite--default: var(--pf-t--global--color--favorite--100);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--color--favorite--200);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--200);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--200);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--color--status--custom--200);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--color--status--custom--100);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--color--status--custom--200);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--color--status--danger--100);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--color--status--info--200);
  --pf-t--global--color--status--info--default: var(--pf-t--global--color--status--info--100);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--color--status--info--200);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--color--status--success--default: var(--pf-t--global--color--status--success--100);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--color--status--warning--200);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--color--status--warning--100);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--color--status--warning--200);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--focus-ring--color--100);
  --pf-t--global--font--size--body--default: var(--pf-t--global--font--size--sm);
  --pf-t--global--font--size--body--lg: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--body--sm: var(--pf-t--global--font--size--xs);
  --pf-t--global--font--size--heading--h1: var(--pf-t--global--font--size--2xl);
  --pf-t--global--font--size--heading--h2: var(--pf-t--global--font--size--xl);
  --pf-t--global--font--size--heading--h3: var(--pf-t--global--font--size--lg);
  --pf-t--global--font--size--heading--h4: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h5: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h6: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--color--severity--critical--100);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--color--severity--important--100);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--color--severity--minor--100);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--color--severity--moderate--100);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--color--severity--none--100);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--color--severity--undefined--100);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--200);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--icon--color--200);
  --pf-t--global--icon--size--font--2xl: var(--pf-t--global--font--size--2xl);
  --pf-t--global--icon--size--font--3xl: var(--pf-t--global--font--size--3xl);
  --pf-t--global--icon--size--font--4xl: var(--pf-t--global--font--size--4xl);
  --pf-t--global--icon--size--font--lg: var(--pf-t--global--font--size--lg);
  --pf-t--global--icon--size--font--md: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--size--font--sm: var(--pf-t--global--font--size--sm);
  --pf-t--global--icon--size--font--xl: var(--pf-t--global--font--size--xl);
  --pf-t--global--icon--size--font--xs: var(--pf-t--global--font--size--xs);
  --pf-t--global--motion--duration--fade--default: var(--pf-t--global--motion--duration--md);
  --pf-t--global--motion--duration--fade--long: var(--pf-t--global--motion--duration--lg);
  --pf-t--global--motion--duration--fade--short: var(--pf-t--global--motion--duration--sm);
  --pf-t--global--motion--duration--icon--default: var(--pf-t--global--motion--duration--sm);
  --pf-t--global--motion--duration--icon--long: var(--pf-t--global--motion--duration--md);
  --pf-t--global--motion--duration--icon--short: var(--pf-t--global--motion--duration--xs);
  --pf-t--global--motion--duration--slide-in--default: var(--pf-t--global--motion--duration--xl);
  --pf-t--global--motion--duration--slide-in--long: var(--pf-t--global--motion--duration--2xl);
  --pf-t--global--motion--duration--slide-in--short: var(--pf-t--global--motion--duration--lg);
  --pf-t--global--motion--duration--slide-out--default: var(--pf-t--global--motion--duration--xl);
  --pf-t--global--motion--duration--slide-out--long: var(--pf-t--global--motion--duration--2xl);
  --pf-t--global--motion--duration--slide-out--short: var(--pf-t--global--motion--duration--lg);
  --pf-t--global--spacer--action--horizontal--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--action--horizontal--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--action--horizontal--plain--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--action--horizontal--plain--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--action--horizontal--spacious: var(--pf-t--global--spacer--xl);
  --pf-t--global--spacer--control--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--control--horizontal--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--spacious: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--control--vertical--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--control--vertical--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--spacious: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--plain: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--control-to-control--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--group--horizontal: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group--vertical: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--default: var(--pf-t--global--spacer--2xl);
  --pf-t--global--spacer--gap--group-to-group--vertical--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group-to-group--vertical--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--gap--text-to-element--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--text-to-element--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gutter--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--inset--page-chrome: var(--pf-t--global--spacer--lg);
  --pf-t--global--text--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--text--color--link--100);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--text--color--link--200);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--text--color--link--300);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--regular: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--text--color--400);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--200);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--300);
  --pf-t--global--text--color--subtle: var(--pf-t--global--text--color--200);
  --pf-t--global--text-decoration--offset--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--text-decoration--width--default: var(--pf-t--global--border--width--regular);
  --pf-t--global--background--color--control--default: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--main--default: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--icon--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--size--font--body--default: var(--pf-t--global--font--size--body--default);
  --pf-t--global--icon--size--font--body--lg: var(--pf-t--global--font--size--body--lg);
  --pf-t--global--icon--size--font--body--sm: var(--pf-t--global--font--size--body--sm);
  --pf-t--global--icon--size--font--heading--h1: var(--pf-t--global--font--size--heading--h1);
  --pf-t--global--icon--size--font--heading--h2: var(--pf-t--global--font--size--heading--h2);
  --pf-t--global--icon--size--font--heading--h3: var(--pf-t--global--font--size--heading--h3);
  --pf-t--global--icon--size--font--heading--h4: var(--pf-t--global--font--size--heading--h4);
  --pf-t--global--icon--size--font--heading--h5: var(--pf-t--global--font--size--heading--h5);
  --pf-t--global--icon--size--font--heading--h6: var(--pf-t--global--font--size--heading--h6);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--text--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--text--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
  --pf-t--global--font--size--heading--xs: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--sm: var(--pf-t--global--font--size--lg);
  --pf-t--global--font--size--heading--md: var(--pf-t--global--font--size--xl);
  --pf-t--global--font--size--heading--lg: var(--pf-t--global--font--size--2xl);
  --pf-t--global--font--size--heading--xl: var(--pf-t--global--font--size--3xl);
  --pf-t--global--font--size--heading--2xl: var(--pf-t--global--font--size--4xl);
  --pf-t--global--font--family--body--legacy: redhattext, helvetica, arial, sans-serif;
  --pf-t--global--font--family--heading--legacy: redhatdisplay, helvetica, arial, sans-serif;
  --pf-t--global--font--family--mono--legacy: redhatmono, liberationmono, consolas, sfmono-regular, menlo, monaco, courier new, monospace;
  --pf-t--global--font--weight--body--legacy: 400;
  --pf-t--global--font--weight--body--bold--legacy: 700;
  --pf-t--global--font--weight--heading--legacy: 400;
  --pf-t--global--font--weight--heading--bold--legacy: 700;
  --pf-t--global--box-shadow--sm: var(--pf-t--global--box-shadow--X--sm--default)
    var(--pf-t--global--box-shadow--Y--sm--default)
    var(--pf-t--global--box-shadow--blur--sm)
    var(--pf-t--global--box-shadow--spread--sm--default)
    var(--pf-t--global--box-shadow--color--sm--default);
  --pf-t--global--box-shadow--sm--top: var(--pf-t--global--box-shadow--X--sm--top)
    var(--pf-t--global--box-shadow--Y--sm--top)
    var(--pf-t--global--box-shadow--blur--sm)
    var(--pf-t--global--box-shadow--spread--sm--directional)
    var(--pf-t--global--box-shadow--color--sm--directional);
  --pf-t--global--box-shadow--sm--bottom: var(--pf-t--global--box-shadow--X--sm--bottom)
    var(--pf-t--global--box-shadow--Y--sm--bottom)
    var(--pf-t--global--box-shadow--blur--sm)
    var(--pf-t--global--box-shadow--spread--sm--directional)
    var(--pf-t--global--box-shadow--color--sm--directional);
  --pf-t--global--box-shadow--sm--left: var(--pf-t--global--box-shadow--X--sm--left)
    var(--pf-t--global--box-shadow--Y--sm--left)
    var(--pf-t--global--box-shadow--blur--sm)
    var(--pf-t--global--box-shadow--spread--sm--directional)
    var(--pf-t--global--box-shadow--color--sm--directional);
  --pf-t--global--box-shadow--sm--right: var(--pf-t--global--box-shadow--X--sm--right)
    var(--pf-t--global--box-shadow--Y--sm--right)
    var(--pf-t--global--box-shadow--blur--sm)
    var(--pf-t--global--box-shadow--spread--sm--directional)
    var(--pf-t--global--box-shadow--color--sm--directional);
  --pf-t--global--box-shadow--md: var(--pf-t--global--box-shadow--X--md--default)
    var(--pf-t--global--box-shadow--Y--md--default)
    var(--pf-t--global--box-shadow--blur--md)
    var(--pf-t--global--box-shadow--spread--md--default)
    var(--pf-t--global--box-shadow--color--md--default);
  --pf-t--global--box-shadow--md--top: var(--pf-t--global--box-shadow--X--md--top)
    var(--pf-t--global--box-shadow--Y--md--top)
    var(--pf-t--global--box-shadow--blur--md)
    var(--pf-t--global--box-shadow--spread--md--directional)
    var(--pf-t--global--box-shadow--color--md--directional);
  --pf-t--global--box-shadow--md--bottom: var(--pf-t--global--box-shadow--X--md--bottom)
    var(--pf-t--global--box-shadow--Y--md--bottom)
    var(--pf-t--global--box-shadow--blur--md)
    var(--pf-t--global--box-shadow--spread--md--directional)
    var(--pf-t--global--box-shadow--color--md--directional);
  --pf-t--global--box-shadow--md--left: var(--pf-t--global--box-shadow--X--md--left)
    var(--pf-t--global--box-shadow--Y--md--left)
    var(--pf-t--global--box-shadow--blur--md)
    var(--pf-t--global--box-shadow--spread--md--directional)
    var(--pf-t--global--box-shadow--color--md--directional);
  --pf-t--global--box-shadow--md--right: var(--pf-t--global--box-shadow--X--md--right)
    var(--pf-t--global--box-shadow--Y--md--right)
    var(--pf-t--global--box-shadow--blur--md)
    var(--pf-t--global--box-shadow--spread--md--directional)
    var(--pf-t--global--box-shadow--color--md--directional);
  --pf-t--global--box-shadow--lg: var(--pf-t--global--box-shadow--X--lg--default)
    var(--pf-t--global--box-shadow--Y--lg--default)
    var(--pf-t--global--box-shadow--blur--lg)
    var(--pf-t--global--box-shadow--spread--lg--default)
    var(--pf-t--global--box-shadow--color--lg--default);
  --pf-t--global--box-shadow--lg--top: var(--pf-t--global--box-shadow--X--lg--top)
    var(--pf-t--global--box-shadow--Y--lg--top)
    var(--pf-t--global--box-shadow--blur--lg)
    var(--pf-t--global--box-shadow--spread--lg--directional)
    var(--pf-t--global--box-shadow--color--lg--directional);
  --pf-t--global--box-shadow--lg--bottom: var(--pf-t--global--box-shadow--X--lg--bottom)
    var(--pf-t--global--box-shadow--Y--lg--bottom)
    var(--pf-t--global--box-shadow--blur--lg)
    var(--pf-t--global--box-shadow--spread--lg--directional)
    var(--pf-t--global--box-shadow--color--lg--directional);
  --pf-t--global--box-shadow--lg--left: var(--pf-t--global--box-shadow--X--lg--left)
    var(--pf-t--global--box-shadow--Y--lg--left)
    var(--pf-t--global--box-shadow--blur--lg)
    var(--pf-t--global--box-shadow--spread--lg--directional)
    var(--pf-t--global--box-shadow--color--lg--directional);
  --pf-t--global--box-shadow--lg--right: var(--pf-t--global--box-shadow--X--lg--right)
    var(--pf-t--global--box-shadow--Y--lg--right)
    var(--pf-t--global--box-shadow--blur--lg)
    var(--pf-t--global--box-shadow--spread--lg--directional)
    var(--pf-t--global--box-shadow--color--lg--directional);
  --pf-t--global--list-style: disc outside;
  --pf-t--temp--dev--tbd: #BC11E0;
}

:root:where(.pf-v6-theme-dark) {
  --pf-t--global--background--color--action--plain--default: rgba(0, 0, 0, 0.0000);
  --pf-t--global--border--color--high-contrast: rgba(255, 255, 255, 0.0000);
  --pf-t--global--dark--background--color--500: rgba(21, 21, 21, 0.8000);
  --pf-t--global--dark--background--color--600: rgba(199, 199, 199, 0.1500);
  --pf-t--global--dark--box-shadow--color--100: rgba(0, 0, 0, 0.5000);
  --pf-t--global--dark--box-shadow--color--200: rgba(0, 0, 0, 0.7000);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--dark--background--color--500);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--dark--background--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--dark--background--color--200: var(--pf-t--color--gray--80);
  --pf-t--global--dark--background--color--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--background--color--400: var(--pf-t--color--gray--10);
  --pf-t--global--dark--background--color--450: var(--pf-t--color--gray--20);
  --pf-t--global--dark--background--color--highlight--100: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--background--color--highlight--200: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--border--color--100: var(--pf-t--color--gray--50);
  --pf-t--global--dark--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--border--color--300: var(--pf-t--color--gray--30);
  --pf-t--global--dark--border--color--50: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--brand--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--brand--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--brand--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--disabled--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--disabled--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--disabled--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--disabled--400: var(--pf-t--color--gray--90);
  --pf-t--global--dark--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--favorite--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--blue--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--nonstatus--blue--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--nonstatus--blue--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--nonstatus--gray--100: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--nonstatus--gray--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--nonstatus--gray--50: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--nonstatus--green--100: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--nonstatus--green--200: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--nonstatus--green--300: var(--pf-t--color--green--10);
  --pf-t--global--dark--color--nonstatus--orange--100: var(--pf-t--color--orange--30);
  --pf-t--global--dark--color--nonstatus--orange--200: var(--pf-t--color--orange--20);
  --pf-t--global--dark--color--nonstatus--orange--300: var(--pf-t--color--orange--10);
  --pf-t--global--dark--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--10);
  --pf-t--global--dark--color--nonstatus--purple--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--nonstatus--purple--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--nonstatus--purple--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--nonstatus--red--100: var(--pf-t--color--red--30);
  --pf-t--global--dark--color--nonstatus--red--200: var(--pf-t--color--red--20);
  --pf-t--global--dark--color--nonstatus--red--300: var(--pf-t--color--red--10);
  --pf-t--global--dark--color--nonstatus--teal--100: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--nonstatus--teal--200: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--nonstatus--teal--300: var(--pf-t--color--teal--10);
  --pf-t--global--dark--color--nonstatus--yellow--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--nonstatus--yellow--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--yellow--300: var(--pf-t--color--yellow--10);
  --pf-t--global--dark--color--severity--critical--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--severity--critical--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--severity--important--100: var(--pf-t--color--orange--40);
  --pf-t--global--dark--color--severity--minor--100: var(--pf-t--color--gray--30);
  --pf-t--global--dark--color--severity--moderate--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--severity--none--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--severity--undefined--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--status--custom--100: var(--pf-t--color--teal--40);
  --pf-t--global--dark--color--status--custom--200: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--status--custom--300: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--status--danger--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--status--danger--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--status--danger--250: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--status--danger--300: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--status--info--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--status--info--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--status--info--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--status--success--100: var(--pf-t--color--green--40);
  --pf-t--global--dark--color--status--success--200: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--status--success--300: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--status--warning--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--focus-ring--color--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--icon--color--100: var(--pf-t--color--gray--10);
  --pf-t--global--dark--icon--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--icon--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--100: var(--pf-t--color--white);
  --pf-t--global--dark--text--color--200: var(--pf-t--color--gray--30);
  --pf-t--global--dark--text--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--400: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--text--color--link--100: var(--pf-t--color--blue--20);
  --pf-t--global--dark--text--color--link--200: var(--pf-t--color--blue--10);
  --pf-t--global--dark--text--color--link--300: var(--pf-t--color--purple--30);
  --pf-t--global--dark--text--color--link--400: var(--pf-t--color--purple--20);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--control--default: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--dark--color--disabled--100);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--dark--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--dark--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--dark--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--primary--default: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--dark--background--color--100);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--border--color--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--dark--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--dark--border--color--200);
  --pf-t--global--border--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--border--color--hover: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--200);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--dark--border--color--200);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--brand--default: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--color--brand--hover: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--favorite--default: var(--pf-t--global--dark--color--favorite--100);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--200);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--200);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--dark--color--status--custom--200);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--dark--color--status--custom--100);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--dark--color--status--custom--200);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--200);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--100);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--200);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--info--default: var(--pf-t--global--dark--color--status--info--100);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--dark--color--status--success--200);
  --pf-t--global--color--status--success--default: var(--pf-t--global--dark--color--status--success--100);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--dark--color--status--success--200);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--dark--color--status--warning--100);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--dark--focus-ring--color--100);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--dark--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--dark--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--dark--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--dark--color--severity--critical--100);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--dark--color--severity--important--100);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--dark--color--severity--minor--100);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--dark--color--severity--moderate--100);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--dark--color--severity--none--100);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--dark--color--severity--undefined--100);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--dark--icon--color--200);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--text--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--dark--text--color--link--100);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--dark--text--color--link--200);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--dark--text--color--link--300);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--dark--color--disabled--300);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--regular: var(--pf-t--global--dark--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--dark--text--color--400);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--250);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--subtle: var(--pf-t--global--dark--text--color--200);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--main--default: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
}

:root:where(.pf-v6-theme-high-contrast) {
  --pf-t--global--background--color--500: rgba(21, 21, 21, 0.2000);
  --pf-t--global--background--color--600: rgba(199, 199, 199, 0.2500);
  --pf-t--global--background--color--action--plain--default: rgba(255, 255, 255, 0.0000);
  --pf-t--global--border--radius--0: 0px;
  --pf-t--global--border--radius--100: 4px;
  --pf-t--global--border--radius--200: 6px;
  --pf-t--global--border--radius--300: 16px;
  --pf-t--global--border--radius--400: 24px;
  --pf-t--global--border--radius--500: 999px;
  --pf-t--global--border--width--100: 1px;
  --pf-t--global--border--width--200: 2px;
  --pf-t--global--border--width--300: 3px;
  --pf-t--global--border--width--400: 4px;
  --pf-t--global--border--width--action--plain--default: 0px;
  --pf-t--global--box-shadow--X--100: -10px;
  --pf-t--global--box-shadow--X--200: -4px;
  --pf-t--global--box-shadow--X--300: -1px;
  --pf-t--global--box-shadow--X--400: 0px;
  --pf-t--global--box-shadow--X--50: -20px;
  --pf-t--global--box-shadow--X--500: 1px;
  --pf-t--global--box-shadow--X--600: 4px;
  --pf-t--global--box-shadow--X--700: 10px;
  --pf-t--global--box-shadow--X--800: 20px;
  --pf-t--global--box-shadow--Y--100: -10px;
  --pf-t--global--box-shadow--Y--200: -4px;
  --pf-t--global--box-shadow--Y--300: -1px;
  --pf-t--global--box-shadow--Y--400: 0px;
  --pf-t--global--box-shadow--Y--50: -20px;
  --pf-t--global--box-shadow--Y--500: 1px;
  --pf-t--global--box-shadow--Y--600: 4px;
  --pf-t--global--box-shadow--Y--700: 10px;
  --pf-t--global--box-shadow--Y--800: 20px;
  --pf-t--global--box-shadow--blur--100: 4px;
  --pf-t--global--box-shadow--blur--200: 9px;
  --pf-t--global--box-shadow--blur--300: 20px;
  --pf-t--global--box-shadow--color--100: rgba(41, 41, 41, 0.1500);
  --pf-t--global--box-shadow--color--200: rgba(41, 41, 41, 0.2000);
  --pf-t--global--box-shadow--spread--100: 0px;
  --pf-t--global--box-shadow--spread--200: -4px;
  --pf-t--global--box-shadow--spread--300: -8px;
  --pf-t--global--box-shadow--spread--400: -20px;
  --pf-t--global--breakpoint--100: 0rem;
  --pf-t--global--breakpoint--200: 36rem;
  --pf-t--global--breakpoint--250: 40rem;
  --pf-t--global--breakpoint--300: 48rem;
  --pf-t--global--breakpoint--350: 60rem;
  --pf-t--global--breakpoint--400: 62rem;
  --pf-t--global--breakpoint--500: 75rem;
  --pf-t--global--breakpoint--550: 80rem;
  --pf-t--global--breakpoint--600: 90.625rem;
  --pf-t--global--color--nonstatus--green--400: #3d7019;
  --pf-t--global--color--status--success--150: #3d7019;
  --pf-t--global--focus-ring--position--inset: -4px;
  --pf-t--global--focus-ring--position--offset: 2px;
  --pf-t--global--focus-ring--width--inset: 3px;
  --pf-t--global--focus-ring--width--offset: 2px;
  --pf-t--global--font--family--100: "Red Hat Text", "RedHatText", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--200: "Red Hat Display", "RedHatDisplay", "Noto Sans Arabic", "Noto Sans Hebrew", "Noto Sans JP", "Noto Sans KR", "Noto Sans Malayalam", "Noto Sans SC", "Noto Sans TC", "Noto Sans Thai", Helvetica, Arial, sans-serif;
  --pf-t--global--font--family--300: "Red Hat Mono", "RedHatMono", "Courier New", Courier, monospace;
  --pf-t--global--font--line-height--100: 1.3;
  --pf-t--global--font--line-height--200: 1.5;
  --pf-t--global--font--size--100: 0.75rem;
  --pf-t--global--font--size--200: 0.875rem;
  --pf-t--global--font--size--300: 1rem;
  --pf-t--global--font--size--400: 1.125rem;
  --pf-t--global--font--size--500: 1.25rem;
  --pf-t--global--font--size--600: 1.5rem;
  --pf-t--global--font--size--700: 1.75rem;
  --pf-t--global--font--size--800: 2.25rem;
  --pf-t--global--font--weight--100: 400;
  --pf-t--global--font--weight--200: 500;
  --pf-t--global--font--weight--300: 500;
  --pf-t--global--font--weight--400: 700;
  --pf-t--global--icon--size--100: 0.75rem;
  --pf-t--global--icon--size--200: 0.875rem;
  --pf-t--global--icon--size--250: 1rem;
  --pf-t--global--icon--size--300: 1.5rem;
  --pf-t--global--icon--size--400: 3.5rem;
  --pf-t--global--icon--size--500: 6rem;
  --pf-t--global--spacer--100: 0.25rem;
  --pf-t--global--spacer--200: 0.5rem;
  --pf-t--global--spacer--300: 1rem;
  --pf-t--global--spacer--400: 1.5rem;
  --pf-t--global--spacer--500: 2rem;
  --pf-t--global--spacer--600: 3rem;
  --pf-t--global--spacer--700: 4rem;
  --pf-t--global--spacer--800: 5rem;
  --pf-t--global--text-decoration--line--100: none;
  --pf-t--global--text-decoration--line--200: underline;
  --pf-t--global--text-decoration--style--100: solid;
  --pf-t--global--text-decoration--style--200: dashed;
  --pf-t--global--z-index--100: 100;
  --pf-t--global--z-index--200: 200;
  --pf-t--global--z-index--300: 300;
  --pf-t--global--z-index--400: 400;
  --pf-t--global--z-index--500: 500;
  --pf-t--global--z-index--600: 600;
  --pf-t--global--background--color--100: var(--pf-t--color--white);
  --pf-t--global--background--color--200: var(--pf-t--color--gray--10);
  --pf-t--global--background--color--300: var(--pf-t--color--gray--20);
  --pf-t--global--background--color--400: var(--pf-t--color--gray--80);
  --pf-t--global--background--color--450: var(--pf-t--color--gray--70);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--background--color--500);
  --pf-t--global--background--color--highlight--100: var(--pf-t--color--yellow--30);
  --pf-t--global--background--color--highlight--200: var(--pf-t--color--yellow--40);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--background--color--600);
  --pf-t--global--border--color--100: var(--pf-t--color--gray--30);
  --pf-t--global--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--border--color--300: var(--pf-t--color--gray--50);
  --pf-t--global--border--color--400: var(--pf-t--color--gray--60);
  --pf-t--global--border--color--50: var(--pf-t--color--gray--20);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--400);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--150);
  --pf-t--global--border--radius--large: var(--pf-t--global--border--radius--400);
  --pf-t--global--border--radius--medium: var(--pf-t--global--border--radius--300);
  --pf-t--global--border--radius--pill: var(--pf-t--global--border--radius--500);
  --pf-t--global--border--radius--sharp: var(--pf-t--global--border--radius--0);
  --pf-t--global--border--radius--small: var(--pf-t--global--border--radius--200);
  --pf-t--global--border--radius--tiny: var(--pf-t--global--border--radius--100);
  --pf-t--global--border--width--action--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--action--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--plain--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--plain--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--clicked: var(--pf-t--global--border--width--300);
  --pf-t--global--border--width--box--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--box--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--status--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--box--status--read: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--control--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--divider--clicked: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--default: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--divider--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--extra-strong: var(--pf-t--global--border--width--300);
  --pf-t--global--border--width--main--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--regular: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--strong: var(--pf-t--global--border--width--200);
  --pf-t--global--box-shadow--X--lg--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--lg--left: var(--pf-t--global--box-shadow--X--50);
  --pf-t--global--box-shadow--X--lg--right: var(--pf-t--global--box-shadow--X--800);
  --pf-t--global--box-shadow--X--lg--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--md--left: var(--pf-t--global--box-shadow--X--100);
  --pf-t--global--box-shadow--X--md--right: var(--pf-t--global--box-shadow--X--700);
  --pf-t--global--box-shadow--X--md--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--bottom: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--default: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--X--sm--left: var(--pf-t--global--box-shadow--X--200);
  --pf-t--global--box-shadow--X--sm--right: var(--pf-t--global--box-shadow--X--600);
  --pf-t--global--box-shadow--X--sm--top: var(--pf-t--global--box-shadow--X--400);
  --pf-t--global--box-shadow--Y--lg--bottom: var(--pf-t--global--box-shadow--Y--800);
  --pf-t--global--box-shadow--Y--lg--default: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--lg--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--lg--top: var(--pf-t--global--box-shadow--Y--50);
  --pf-t--global--box-shadow--Y--md--bottom: var(--pf-t--global--box-shadow--Y--700);
  --pf-t--global--box-shadow--Y--md--default: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--md--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--md--top: var(--pf-t--global--box-shadow--Y--100);
  --pf-t--global--box-shadow--Y--sm--bottom: var(--pf-t--global--box-shadow--Y--600);
  --pf-t--global--box-shadow--Y--sm--default: var(--pf-t--global--box-shadow--Y--500);
  --pf-t--global--box-shadow--Y--sm--left: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--right: var(--pf-t--global--box-shadow--Y--400);
  --pf-t--global--box-shadow--Y--sm--top: var(--pf-t--global--box-shadow--Y--200);
  --pf-t--global--box-shadow--blur--lg: var(--pf-t--global--box-shadow--blur--300);
  --pf-t--global--box-shadow--blur--md: var(--pf-t--global--box-shadow--blur--200);
  --pf-t--global--box-shadow--blur--sm: var(--pf-t--global--box-shadow--blur--100);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--box-shadow--color--200);
  --pf-t--global--box-shadow--spread--lg--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--lg--directional: var(--pf-t--global--box-shadow--spread--400);
  --pf-t--global--box-shadow--spread--md--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--md--directional: var(--pf-t--global--box-shadow--spread--300);
  --pf-t--global--box-shadow--spread--sm--default: var(--pf-t--global--box-shadow--spread--100);
  --pf-t--global--box-shadow--spread--sm--directional: var(--pf-t--global--box-shadow--spread--200);
  --pf-t--global--breakpoint--2xl: var(--pf-t--global--breakpoint--600);
  --pf-t--global--breakpoint--height--2xl: var(--pf-t--global--breakpoint--550);
  --pf-t--global--breakpoint--height--lg: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--height--md: var(--pf-t--global--breakpoint--250);
  --pf-t--global--breakpoint--height--sm: var(--pf-t--global--breakpoint--100);
  --pf-t--global--breakpoint--height--xl: var(--pf-t--global--breakpoint--350);
  --pf-t--global--breakpoint--lg: var(--pf-t--global--breakpoint--400);
  --pf-t--global--breakpoint--md: var(--pf-t--global--breakpoint--300);
  --pf-t--global--breakpoint--sm: var(--pf-t--global--breakpoint--200);
  --pf-t--global--breakpoint--xl: var(--pf-t--global--breakpoint--500);
  --pf-t--global--breakpoint--xs: var(--pf-t--global--breakpoint--100);
  --pf-t--global--color--brand--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--brand--200: var(--pf-t--color--blue--50);
  --pf-t--global--color--brand--300: var(--pf-t--color--blue--60);
  --pf-t--global--color--brand--400: var(--pf-t--color--blue--70);
  --pf-t--global--color--brand--500: var(--pf-t--color--blue--80);
  --pf-t--global--color--disabled--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--disabled--200: var(--pf-t--color--gray--40);
  --pf-t--global--color--disabled--300: var(--pf-t--color--gray--60);
  --pf-t--global--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--favorite--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--favorite--300: var(--pf-t--color--yellow--70);
  --pf-t--global--color--favorite--400: var(--pf-t--color--yellow--80);
  --pf-t--global--color--nonstatus--blue--100: var(--pf-t--color--blue--20);
  --pf-t--global--color--nonstatus--blue--200: var(--pf-t--color--blue--30);
  --pf-t--global--color--nonstatus--blue--300: var(--pf-t--color--blue--40);
  --pf-t--global--color--nonstatus--blue--400: var(--pf-t--color--blue--60);
  --pf-t--global--color--nonstatus--blue--500: var(--pf-t--color--blue--70);
  --pf-t--global--color--nonstatus--gray--100: var(--pf-t--color--gray--20);
  --pf-t--global--color--nonstatus--gray--200: var(--pf-t--color--gray--30);
  --pf-t--global--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--color--nonstatus--gray--400: var(--pf-t--color--gray--60);
  --pf-t--global--color--nonstatus--gray--50: var(--pf-t--color--gray--10);
  --pf-t--global--color--nonstatus--gray--500: var(--pf-t--color--gray--70);
  --pf-t--global--color--nonstatus--green--100: var(--pf-t--color--green--20);
  --pf-t--global--color--nonstatus--green--200: var(--pf-t--color--green--30);
  --pf-t--global--color--nonstatus--green--300: var(--pf-t--color--green--40);
  --pf-t--global--color--nonstatus--green--500: var(--pf-t--color--green--70);
  --pf-t--global--color--nonstatus--orange--100: var(--pf-t--color--orange--20);
  --pf-t--global--color--nonstatus--orange--200: var(--pf-t--color--orange--30);
  --pf-t--global--color--nonstatus--orange--300: var(--pf-t--color--orange--40);
  --pf-t--global--color--nonstatus--orange--400: var(--pf-t--color--orange--60);
  --pf-t--global--color--nonstatus--orange--500: var(--pf-t--color--orange--70);
  --pf-t--global--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--20);
  --pf-t--global--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--30);
  --pf-t--global--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--40);
  --pf-t--global--color--nonstatus--orangered--400: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--nonstatus--orangered--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--nonstatus--purple--100: var(--pf-t--color--purple--20);
  --pf-t--global--color--nonstatus--purple--200: var(--pf-t--color--purple--30);
  --pf-t--global--color--nonstatus--purple--300: var(--pf-t--color--purple--40);
  --pf-t--global--color--nonstatus--purple--400: var(--pf-t--color--purple--50);
  --pf-t--global--color--nonstatus--purple--500: var(--pf-t--color--purple--60);
  --pf-t--global--color--nonstatus--red--100: var(--pf-t--color--red--20);
  --pf-t--global--color--nonstatus--red--200: var(--pf-t--color--red--30);
  --pf-t--global--color--nonstatus--red--300: var(--pf-t--color--red--40);
  --pf-t--global--color--nonstatus--red--400: var(--pf-t--color--red--60);
  --pf-t--global--color--nonstatus--red--500: var(--pf-t--color--red--70);
  --pf-t--global--color--nonstatus--teal--100: var(--pf-t--color--teal--20);
  --pf-t--global--color--nonstatus--teal--200: var(--pf-t--color--teal--30);
  --pf-t--global--color--nonstatus--teal--300: var(--pf-t--color--teal--40);
  --pf-t--global--color--nonstatus--teal--400: var(--pf-t--color--teal--70);
  --pf-t--global--color--nonstatus--teal--500: var(--pf-t--color--teal--80);
  --pf-t--global--color--nonstatus--yellow--100: var(--pf-t--color--yellow--20);
  --pf-t--global--color--nonstatus--yellow--200: var(--pf-t--color--yellow--30);
  --pf-t--global--color--nonstatus--yellow--300: var(--pf-t--color--yellow--40);
  --pf-t--global--color--nonstatus--yellow--400: var(--pf-t--color--yellow--70);
  --pf-t--global--color--nonstatus--yellow--500: var(--pf-t--color--yellow--80);
  --pf-t--global--color--severity--critical--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--severity--important--100: var(--pf-t--color--orange--50);
  --pf-t--global--color--severity--important--200: var(--pf-t--color--orange--60);
  --pf-t--global--color--severity--minor--100: var(--pf-t--color--gray--50);
  --pf-t--global--color--severity--minor--200: var(--pf-t--color--gray--80);
  --pf-t--global--color--severity--moderate--100: var(--pf-t--color--yellow--40);
  --pf-t--global--color--severity--moderate--200: var(--pf-t--color--yellow--70);
  --pf-t--global--color--severity--none--100: var(--pf-t--color--blue--40);
  --pf-t--global--color--severity--none--200: var(--pf-t--color--blue--60);
  --pf-t--global--color--severity--undefined--100: var(--pf-t--color--gray--30);
  --pf-t--global--color--severity--undefined--200: var(--pf-t--color--gray--60);
  --pf-t--global--color--status--custom--100: var(--pf-t--color--teal--60);
  --pf-t--global--color--status--custom--200: var(--pf-t--color--teal--70);
  --pf-t--global--color--status--custom--300: var(--pf-t--color--teal--80);
  --pf-t--global--color--status--danger--100: var(--pf-t--color--red-orange--60);
  --pf-t--global--color--status--danger--200: var(--pf-t--color--red-orange--70);
  --pf-t--global--color--status--danger--300: var(--pf-t--color--red-orange--80);
  --pf-t--global--color--status--info--100: var(--pf-t--color--purple--50);
  --pf-t--global--color--status--info--200: var(--pf-t--color--purple--60);
  --pf-t--global--color--status--info--300: var(--pf-t--color--purple--70);
  --pf-t--global--color--status--success--100: var(--pf-t--color--green--60);
  --pf-t--global--color--status--success--200: var(--pf-t--color--green--70);
  --pf-t--global--color--status--success--300: var(--pf-t--color--green--80);
  --pf-t--global--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--color--status--warning--200: var(--pf-t--color--yellow--40);
  --pf-t--global--color--status--warning--300: var(--pf-t--color--yellow--50);
  --pf-t--global--color--status--warning--400: var(--pf-t--color--yellow--60);
  --pf-t--global--color--status--warning--500: var(--pf-t--color--yellow--70);
  --pf-t--global--color--status--warning--600: var(--pf-t--color--yellow--80);
  --pf-t--global--focus-ring--color--100: var(--pf-t--color--blue--50);
  --pf-t--global--focus-ring--color--200: var(--pf-t--color--blue--60);
  --pf-t--global--font--family--body: var(--pf-t--global--font--family--100);
  --pf-t--global--font--family--heading: var(--pf-t--global--font--family--200);
  --pf-t--global--font--family--mono: var(--pf-t--global--font--family--300);
  --pf-t--global--font--line-height--body: var(--pf-t--global--font--line-height--200);
  --pf-t--global--font--line-height--heading: var(--pf-t--global--font--line-height--100);
  --pf-t--global--font--size--2xl: var(--pf-t--global--font--size--600);
  --pf-t--global--font--size--3xl: var(--pf-t--global--font--size--700);
  --pf-t--global--font--size--4xl: var(--pf-t--global--font--size--800);
  --pf-t--global--font--size--lg: var(--pf-t--global--font--size--400);
  --pf-t--global--font--size--md: var(--pf-t--global--font--size--300);
  --pf-t--global--font--size--sm: var(--pf-t--global--font--size--200);
  --pf-t--global--font--size--xl: var(--pf-t--global--font--size--500);
  --pf-t--global--font--size--xs: var(--pf-t--global--font--size--100);
  --pf-t--global--font--weight--body--bold: var(--pf-t--global--font--weight--200);
  --pf-t--global--font--weight--body--default: var(--pf-t--global--font--weight--100);
  --pf-t--global--font--weight--heading--bold: var(--pf-t--global--font--weight--400);
  --pf-t--global--font--weight--heading--default: var(--pf-t--global--font--weight--300);
  --pf-t--global--icon--color--100: var(--pf-t--color--gray--90);
  --pf-t--global--icon--color--150: var(--pf-t--color--gray--60);
  --pf-t--global--icon--color--200: var(--pf-t--color--gray--50);
  --pf-t--global--icon--color--300: var(--pf-t--color--white);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--color--blue--70);
  --pf-t--global--icon--color--brand--default: var(--pf-t--color--blue--60);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--color--blue--70);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--150);
  --pf-t--global--icon--size--2xl: var(--pf-t--global--icon--size--400);
  --pf-t--global--icon--size--3xl: var(--pf-t--global--icon--size--500);
  --pf-t--global--icon--size--lg: var(--pf-t--global--icon--size--250);
  --pf-t--global--icon--size--md: var(--pf-t--global--icon--size--200);
  --pf-t--global--icon--size--sm: var(--pf-t--global--icon--size--100);
  --pf-t--global--icon--size--xl: var(--pf-t--global--icon--size--300);
  --pf-t--global--spacer--2xl: var(--pf-t--global--spacer--600);
  --pf-t--global--spacer--3xl: var(--pf-t--global--spacer--700);
  --pf-t--global--spacer--4xl: var(--pf-t--global--spacer--800);
  --pf-t--global--spacer--lg: var(--pf-t--global--spacer--400);
  --pf-t--global--spacer--md: var(--pf-t--global--spacer--300);
  --pf-t--global--spacer--sm: var(--pf-t--global--spacer--200);
  --pf-t--global--spacer--xl: var(--pf-t--global--spacer--500);
  --pf-t--global--spacer--xs: var(--pf-t--global--spacer--100);
  --pf-t--global--text--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--text--color--200: var(--pf-t--color--gray--60);
  --pf-t--global--text--color--250: var(--pf-t--color--gray--70);
  --pf-t--global--text--color--300: var(--pf-t--color--white);
  --pf-t--global--text--color--400: var(--pf-t--color--red-orange--40);
  --pf-t--global--text--color--500: var(--pf-t--color--red-orange--70);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--color--blue--80);
  --pf-t--global--text--color--brand--default: var(--pf-t--color--blue--70);
  --pf-t--global--text--color--brand--hover: var(--pf-t--color--blue--80);
  --pf-t--global--text--color--link--100: var(--pf-t--color--blue--50);
  --pf-t--global--text--color--link--200: var(--pf-t--color--blue--60);
  --pf-t--global--text--color--link--250: var(--pf-t--color--blue--70);
  --pf-t--global--text--color--link--300: var(--pf-t--color--purple--50);
  --pf-t--global--text--color--link--350: var(--pf-t--color--purple--60);
  --pf-t--global--text-decoration--editable-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--editable-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--editable-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--help-text--style--default: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--help-text--style--hover: var(--pf-t--global--text-decoration--style--200);
  --pf-t--global--text-decoration--link--line--default: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--line--hover: var(--pf-t--global--text-decoration--line--200);
  --pf-t--global--text-decoration--link--style--default: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--text-decoration--link--style--hover: var(--pf-t--global--text-decoration--style--100);
  --pf-t--global--z-index--2xl: var(--pf-t--global--z-index--600);
  --pf-t--global--z-index--lg: var(--pf-t--global--z-index--400);
  --pf-t--global--z-index--md: var(--pf-t--global--z-index--300);
  --pf-t--global--z-index--sm: var(--pf-t--global--z-index--200);
  --pf-t--global--z-index--xl: var(--pf-t--global--z-index--500);
  --pf-t--global--z-index--xs: var(--pf-t--global--z-index--100);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--color--disabled--100);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--primary--default: var(--pf-t--global--background--color--100);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--background--color--300);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--background--color--200);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--background--color--300);
  --pf-t--global--border--color--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--border--color--hover: var(--pf-t--global--color--brand--300);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--400);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--400);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--400);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--400);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--400);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--400);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--400);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--400);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--width--high-contrast--extra-strong: var(--pf-t--global--border--width--extra-strong);
  --pf-t--global--border--width--high-contrast--regular: var(--pf-t--global--border--width--regular);
  --pf-t--global--border--width--high-contrast--strong: var(--pf-t--global--border--width--strong);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--brand--default: var(--pf-t--global--color--brand--300);
  --pf-t--global--color--brand--hover: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--favorite--default: var(--pf-t--global--color--favorite--300);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--50);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--color--status--custom--200);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--info--default: var(--pf-t--global--color--status--info--200);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--focus-ring--color--200);
  --pf-t--global--font--size--body--default: var(--pf-t--global--font--size--sm);
  --pf-t--global--font--size--body--lg: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--body--sm: var(--pf-t--global--font--size--xs);
  --pf-t--global--font--size--heading--h1: var(--pf-t--global--font--size--2xl);
  --pf-t--global--font--size--heading--h2: var(--pf-t--global--font--size--xl);
  --pf-t--global--font--size--heading--h3: var(--pf-t--global--font--size--lg);
  --pf-t--global--font--size--heading--h4: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h5: var(--pf-t--global--font--size--md);
  --pf-t--global--font--size--heading--h6: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--color--severity--critical--100);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--color--severity--important--200);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--color--severity--minor--200);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--color--severity--moderate--200);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--color--severity--none--200);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--color--severity--undefined--200);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--100);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--icon--color--150);
  --pf-t--global--icon--size--font--2xl: var(--pf-t--global--font--size--2xl);
  --pf-t--global--icon--size--font--3xl: var(--pf-t--global--font--size--3xl);
  --pf-t--global--icon--size--font--4xl: var(--pf-t--global--font--size--4xl);
  --pf-t--global--icon--size--font--lg: var(--pf-t--global--font--size--lg);
  --pf-t--global--icon--size--font--md: var(--pf-t--global--font--size--md);
  --pf-t--global--icon--size--font--sm: var(--pf-t--global--font--size--sm);
  --pf-t--global--icon--size--font--xl: var(--pf-t--global--font--size--xl);
  --pf-t--global--icon--size--font--xs: var(--pf-t--global--font--size--xs);
  --pf-t--global--spacer--action--horizontal--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--action--horizontal--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--action--horizontal--plain--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--action--horizontal--plain--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--action--horizontal--spacious: var(--pf-t--global--spacer--xl);
  --pf-t--global--spacer--control--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--control--horizontal--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--horizontal--spacious: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--control--vertical--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--control--vertical--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--plain: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--control--vertical--spacious: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--action-to-action--plain: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--control-to-control--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--group--horizontal: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group--vertical: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--compact: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gap--group-to-group--horizontal--default: var(--pf-t--global--spacer--2xl);
  --pf-t--global--spacer--gap--group-to-group--vertical--compact: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--gap--group-to-group--vertical--default: var(--pf-t--global--spacer--lg);
  --pf-t--global--spacer--gap--text-to-element--compact: var(--pf-t--global--spacer--xs);
  --pf-t--global--spacer--gap--text-to-element--default: var(--pf-t--global--spacer--sm);
  --pf-t--global--spacer--gutter--default: var(--pf-t--global--spacer--md);
  --pf-t--global--spacer--inset--page-chrome: var(--pf-t--global--spacer--lg);
  --pf-t--global--text--color--disabled: var(--pf-t--global--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--text--color--link--200);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--text--color--link--250);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--text--color--link--350);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--color--disabled--300);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--regular: var(--pf-t--global--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--text--color--500);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--subtle: var(--pf-t--global--text--color--250);
  --pf-t--global--text-decoration--offset--default: var(--pf-t--global--spacer--xs);
  --pf-t--global--text-decoration--width--default: var(--pf-t--global--border--width--regular);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--control--default: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--high-contrast: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--main--default: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--size--font--body--default: var(--pf-t--global--font--size--body--default);
  --pf-t--global--icon--size--font--body--lg: var(--pf-t--global--font--size--body--lg);
  --pf-t--global--icon--size--font--body--sm: var(--pf-t--global--font--size--body--sm);
  --pf-t--global--icon--size--font--heading--h1: var(--pf-t--global--font--size--heading--h1);
  --pf-t--global--icon--size--font--heading--h2: var(--pf-t--global--font--size--heading--h2);
  --pf-t--global--icon--size--font--heading--h3: var(--pf-t--global--font--size--heading--h3);
  --pf-t--global--icon--size--font--heading--h4: var(--pf-t--global--font--size--heading--h4);
  --pf-t--global--icon--size--font--heading--h5: var(--pf-t--global--font--size--heading--h5);
  --pf-t--global--icon--size--font--heading--h6: var(--pf-t--global--font--size--heading--h6);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
}

:root:where(.pf-v6-theme-high-contrast.pf-v6-theme-dark) {
  --pf-t--global--background--color--action--plain--default: rgba(0, 0, 0, 0.0000);
  --pf-t--global--dark--background--color--500: rgba(21, 21, 21, 0.8000);
  --pf-t--global--dark--background--color--600: rgba(199, 199, 199, 0.1500);
  --pf-t--global--dark--box-shadow--color--100: rgba(0, 0, 0, 0.5000);
  --pf-t--global--dark--box-shadow--color--200: rgba(0, 0, 0, 0.7000);
  --pf-t--global--background--color--action--plain--clicked: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--action--plain--hover: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--background--color--backdrop--default: var(--pf-t--global--dark--background--color--500);
  --pf-t--global--background--color--primary--default: var(--pf-t--color--black);
  --pf-t--global--background--color--tertiary--default: var(--pf-t--global--dark--background--color--600);
  --pf-t--global--box-shadow--color--lg--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--lg--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--md--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--md--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--box-shadow--color--sm--default: var(--pf-t--global--dark--box-shadow--color--100);
  --pf-t--global--box-shadow--color--sm--directional: var(--pf-t--global--dark--box-shadow--color--200);
  --pf-t--global--dark--background--color--100: var(--pf-t--color--gray--95);
  --pf-t--global--dark--background--color--200: var(--pf-t--color--gray--80);
  --pf-t--global--dark--background--color--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--background--color--400: var(--pf-t--color--gray--10);
  --pf-t--global--dark--background--color--450: var(--pf-t--color--gray--20);
  --pf-t--global--dark--background--color--highlight--100: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--background--color--highlight--200: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--border--color--100: var(--pf-t--color--gray--50);
  --pf-t--global--dark--border--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--border--color--300: var(--pf-t--color--gray--30);
  --pf-t--global--dark--border--color--50: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--brand--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--brand--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--brand--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--disabled--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--disabled--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--disabled--300: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--disabled--400: var(--pf-t--color--gray--90);
  --pf-t--global--dark--color--favorite--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--favorite--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--blue--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--nonstatus--blue--200: var(--pf-t--color--blue--20);
  --pf-t--global--dark--color--nonstatus--blue--300: var(--pf-t--color--blue--10);
  --pf-t--global--dark--color--nonstatus--gray--100: var(--pf-t--color--gray--60);
  --pf-t--global--dark--color--nonstatus--gray--200: var(--pf-t--color--gray--50);
  --pf-t--global--dark--color--nonstatus--gray--300: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--nonstatus--gray--50: var(--pf-t--color--gray--70);
  --pf-t--global--dark--color--nonstatus--green--100: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--nonstatus--green--200: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--nonstatus--green--300: var(--pf-t--color--green--10);
  --pf-t--global--dark--color--nonstatus--orange--100: var(--pf-t--color--orange--30);
  --pf-t--global--dark--color--nonstatus--orange--200: var(--pf-t--color--orange--20);
  --pf-t--global--dark--color--nonstatus--orange--300: var(--pf-t--color--orange--10);
  --pf-t--global--dark--color--nonstatus--orangered--100: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--nonstatus--orangered--200: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--nonstatus--orangered--300: var(--pf-t--color--red-orange--10);
  --pf-t--global--dark--color--nonstatus--purple--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--nonstatus--purple--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--nonstatus--purple--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--nonstatus--red--100: var(--pf-t--color--red--30);
  --pf-t--global--dark--color--nonstatus--red--200: var(--pf-t--color--red--20);
  --pf-t--global--dark--color--nonstatus--red--300: var(--pf-t--color--red--10);
  --pf-t--global--dark--color--nonstatus--teal--100: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--nonstatus--teal--200: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--nonstatus--teal--300: var(--pf-t--color--teal--10);
  --pf-t--global--dark--color--nonstatus--yellow--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--nonstatus--yellow--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--color--nonstatus--yellow--300: var(--pf-t--color--yellow--10);
  --pf-t--global--dark--color--severity--critical--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--severity--critical--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--severity--important--100: var(--pf-t--color--orange--40);
  --pf-t--global--dark--color--severity--minor--100: var(--pf-t--color--gray--30);
  --pf-t--global--dark--color--severity--moderate--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--severity--none--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--color--severity--undefined--100: var(--pf-t--color--gray--40);
  --pf-t--global--dark--color--status--custom--100: var(--pf-t--color--teal--40);
  --pf-t--global--dark--color--status--custom--200: var(--pf-t--color--teal--30);
  --pf-t--global--dark--color--status--custom--300: var(--pf-t--color--teal--20);
  --pf-t--global--dark--color--status--danger--100: var(--pf-t--color--red-orange--50);
  --pf-t--global--dark--color--status--danger--200: var(--pf-t--color--red-orange--40);
  --pf-t--global--dark--color--status--danger--250: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--color--status--danger--300: var(--pf-t--color--red-orange--20);
  --pf-t--global--dark--color--status--info--100: var(--pf-t--color--purple--30);
  --pf-t--global--dark--color--status--info--200: var(--pf-t--color--purple--20);
  --pf-t--global--dark--color--status--info--300: var(--pf-t--color--purple--10);
  --pf-t--global--dark--color--status--success--100: var(--pf-t--color--green--40);
  --pf-t--global--dark--color--status--success--200: var(--pf-t--color--green--30);
  --pf-t--global--dark--color--status--success--300: var(--pf-t--color--green--20);
  --pf-t--global--dark--color--status--warning--100: var(--pf-t--color--yellow--30);
  --pf-t--global--dark--color--status--warning--200: var(--pf-t--color--yellow--20);
  --pf-t--global--dark--focus-ring--color--100: var(--pf-t--color--blue--30);
  --pf-t--global--dark--icon--color--100: var(--pf-t--color--gray--10);
  --pf-t--global--dark--icon--color--200: var(--pf-t--color--gray--40);
  --pf-t--global--dark--icon--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--100: var(--pf-t--color--white);
  --pf-t--global--dark--text--color--200: var(--pf-t--color--gray--30);
  --pf-t--global--dark--text--color--300: var(--pf-t--color--gray--90);
  --pf-t--global--dark--text--color--400: var(--pf-t--color--red-orange--30);
  --pf-t--global--dark--text--color--link--100: var(--pf-t--color--blue--20);
  --pf-t--global--dark--text--color--link--200: var(--pf-t--color--blue--10);
  --pf-t--global--dark--text--color--link--300: var(--pf-t--color--purple--30);
  --pf-t--global--dark--text--color--link--400: var(--pf-t--color--purple--20);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--control--default: var(--pf-t--global--dark--background--color--100);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--disabled--default: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--highlight--clicked: var(--pf-t--global--dark--background--color--highlight--200);
  --pf-t--global--background--color--highlight--default: var(--pf-t--global--dark--background--color--highlight--100);
  --pf-t--global--background--color--inverse--clicked: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--inverse--default: var(--pf-t--global--dark--background--color--400);
  --pf-t--global--background--color--inverse--hover: var(--pf-t--global--dark--background--color--450);
  --pf-t--global--background--color--primary--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--primary--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--secondary--clicked: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--secondary--default: var(--pf-t--global--dark--background--color--100);
  --pf-t--global--background--color--secondary--hover: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--border--color--alt: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--dark--border--color--50);
  --pf-t--global--border--color--default: var(--pf-t--global--dark--border--color--300);
  --pf-t--global--border--color--disabled: var(--pf-t--global--dark--color--disabled--100);
  --pf-t--global--border--color--hover: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--200);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--300);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--dark--border--color--300);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--brand--default: var(--pf-t--global--dark--color--brand--100);
  --pf-t--global--color--brand--hover: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--favorite--default: var(--pf-t--global--dark--color--favorite--100);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--dark--color--favorite--200);
  --pf-t--global--color--nonstatus--blue--clicked: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--blue--default: var(--pf-t--global--dark--color--nonstatus--blue--100);
  --pf-t--global--color--nonstatus--blue--hover: var(--pf-t--global--dark--color--nonstatus--blue--200);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--dark--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--dark--color--nonstatus--gray--50);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--dark--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--green--clicked: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--green--default: var(--pf-t--global--dark--color--nonstatus--green--100);
  --pf-t--global--color--nonstatus--green--hover: var(--pf-t--global--dark--color--nonstatus--green--200);
  --pf-t--global--color--nonstatus--orange--clicked: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orange--default: var(--pf-t--global--dark--color--nonstatus--orange--100);
  --pf-t--global--color--nonstatus--orange--hover: var(--pf-t--global--dark--color--nonstatus--orange--200);
  --pf-t--global--color--nonstatus--orangered--clicked: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--orangered--default: var(--pf-t--global--dark--color--nonstatus--orangered--100);
  --pf-t--global--color--nonstatus--orangered--hover: var(--pf-t--global--dark--color--nonstatus--orangered--200);
  --pf-t--global--color--nonstatus--purple--clicked: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--purple--default: var(--pf-t--global--dark--color--nonstatus--purple--100);
  --pf-t--global--color--nonstatus--purple--hover: var(--pf-t--global--dark--color--nonstatus--purple--200);
  --pf-t--global--color--nonstatus--red--clicked: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--red--default: var(--pf-t--global--dark--color--nonstatus--red--100);
  --pf-t--global--color--nonstatus--red--hover: var(--pf-t--global--dark--color--nonstatus--red--200);
  --pf-t--global--color--nonstatus--teal--clicked: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--teal--default: var(--pf-t--global--dark--color--nonstatus--teal--100);
  --pf-t--global--color--nonstatus--teal--hover: var(--pf-t--global--dark--color--nonstatus--teal--200);
  --pf-t--global--color--nonstatus--yellow--clicked: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--nonstatus--yellow--default: var(--pf-t--global--dark--color--nonstatus--yellow--100);
  --pf-t--global--color--nonstatus--yellow--hover: var(--pf-t--global--dark--color--nonstatus--yellow--200);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--dark--color--status--custom--300);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--dark--color--status--custom--200);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--dark--color--status--custom--300);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--250);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--200);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--250);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--info--default: var(--pf-t--global--dark--color--status--info--100);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--dark--color--status--info--200);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--dark--color--status--success--300);
  --pf-t--global--color--status--success--default: var(--pf-t--global--dark--color--status--success--200);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--dark--color--status--success--300);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--dark--color--status--warning--100);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--dark--color--status--warning--200);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--dark--focus-ring--color--100);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--icon--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--icon--color--inverse: var(--pf-t--global--dark--icon--color--300);
  --pf-t--global--icon--color--on-disabled: var(--pf-t--global--dark--color--disabled--300);
  --pf-t--global--icon--color--regular: var(--pf-t--global--dark--icon--color--100);
  --pf-t--global--icon--color--severity--critical--default: var(--pf-t--global--dark--color--severity--critical--200);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--dark--color--severity--important--100);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--dark--color--severity--minor--100);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--dark--color--severity--moderate--100);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--dark--color--severity--none--100);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--dark--color--severity--undefined--100);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--dark--icon--color--200);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--brand--default: var(--pf-t--global--dark--color--brand--200);
  --pf-t--global--text--color--brand--hover: var(--pf-t--global--dark--color--brand--300);
  --pf-t--global--text--color--disabled: var(--pf-t--global--dark--color--disabled--200);
  --pf-t--global--text--color--inverse: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--link--default: var(--pf-t--global--dark--text--color--link--100);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--dark--text--color--link--200);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--dark--text--color--link--400);
  --pf-t--global--text--color--on-disabled: var(--pf-t--global--dark--color--disabled--400);
  --pf-t--global--text--color--on-highlight: var(--pf-t--global--dark--text--color--300);
  --pf-t--global--text--color--regular: var(--pf-t--global--dark--text--color--100);
  --pf-t--global--text--color--required: var(--pf-t--global--dark--text--color--400);
  --pf-t--global--text--color--status--danger--clicked: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--status--danger--default: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--status--danger--hover: var(--pf-t--global--dark--color--status--danger--300);
  --pf-t--global--text--color--subtle: var(--pf-t--global--dark--text--color--200);
  --pf-t--global--border--color--brand--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--border--color--brand--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--border--color--brand--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--border--color--high-contrast: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--main--default: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--border--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--border--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--border--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--border--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--border--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--border--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--border--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--border--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--color--status--read--on-primary: var(--pf-t--global--background--color--secondary--default);
  --pf-t--global--color--status--read--on-secondary: var(--pf-t--global--background--color--control--default);
  --pf-t--global--color--status--unread--attention--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--color--status--unread--attention--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--color--status--unread--attention--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--color--status--unread--clicked: var(--pf-t--global--color--brand--clicked);
  --pf-t--global--color--status--unread--default: var(--pf-t--global--color--brand--default);
  --pf-t--global--color--status--unread--hover: var(--pf-t--global--color--brand--hover);
  --pf-t--global--icon--color--favorite--clicked: var(--pf-t--global--color--favorite--clicked);
  --pf-t--global--icon--color--favorite--default: var(--pf-t--global--color--favorite--default);
  --pf-t--global--icon--color--favorite--hover: var(--pf-t--global--color--favorite--hover);
  --pf-t--global--icon--color--nonstatus--on-blue--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-blue--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-gray--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-gray--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--nonstatus--on-green--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-green--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orange--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-orangered--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-purple--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-red--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-teal--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--nonstatus--on-yellow--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--on-brand--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--icon--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--icon--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--clicked);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--default);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--hover);
  --pf-t--global--icon--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--icon--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--icon--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--icon--color--status--on-custom--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-custom--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-danger--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-info--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-success--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--icon--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--icon--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--icon--color--status--unread--on-attention--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-attention--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--unread--on-default--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
  --pf-t--global--text--color--nonstatus--on-blue--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-blue--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-gray--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-gray--hover: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--nonstatus--on-green--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-green--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orange--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-orangered--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-purple--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-red--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-teal--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--nonstatus--on-yellow--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--on-brand--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--placeholder: var(--pf-t--global--text--color--subtle);
  --pf-t--global--text--color--status--custom--clicked: var(--pf-t--global--color--status--custom--clicked);
  --pf-t--global--text--color--status--custom--default: var(--pf-t--global--color--status--custom--default);
  --pf-t--global--text--color--status--custom--hover: var(--pf-t--global--color--status--custom--hover);
  --pf-t--global--text--color--status--info--clicked: var(--pf-t--global--color--status--info--clicked);
  --pf-t--global--text--color--status--info--default: var(--pf-t--global--color--status--info--default);
  --pf-t--global--text--color--status--info--hover: var(--pf-t--global--color--status--info--hover);
  --pf-t--global--text--color--status--on-custom--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-custom--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-danger--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-info--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-success--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--clicked);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--default);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--hover);
  --pf-t--global--text--color--status--unread--on-attention--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-attention--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--unread--on-default--hover: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--clicked);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--default);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--hover);
}

:is(.pf-v6-m-dir-rtl, [dir=rtl]) {
  --pf-v6-global--inverse--multiplier: -1;
}